(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    132087,       2912]*)
(*NotebookOutlinePosition[    132722,       2934]*)
(*  CellTagsIndexPosition[    132678,       2930]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    \(makemonic[p_, x_] := 
      Module[{n}, \[IndentingNewLine]n = 
          Exponent[p, x]; \[IndentingNewLine]Expand[
          p/Coefficient[p, x, n]]\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[{
    \(\(Clear[RothsteinTrager];\)\), "\[IndentingNewLine]", 
    \(RothsteinTrager[r_, x_] := 
      Module[{c, d, dmonic, z, res, sol, zlist, 
          vlist}, \[IndentingNewLine]c = Numerator[r]; \[IndentingNewLine]d = 
          Denominator[r]; \[IndentingNewLine]dmonic = 
          makemonic[d, x]; \[IndentingNewLine]c = 
          Together[c*dmonic/d]; \[IndentingNewLine]d = 
          dmonic; \[IndentingNewLine]res = 
          Resultant[c - z*D[d, x], d, x]; \[IndentingNewLine]sol = 
          Union[Solve[res \[Equal] 0, z]]; \[IndentingNewLine]zlist = 
          z /. sol; \[IndentingNewLine]vlist = 
          PolynomialGCD[c - z*D[d, x] /. sol, d, 
            Extension \[Rule] Automatic]; \[IndentingNewLine]zlist\  . \ 
          Log[makemonic[vlist, x]]\[IndentingNewLine]]\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(r = \(x\^4 - 3  x\^2 + 6\)\/\(x\^6 - 5  x\^4 + 5  x\^2 + 4\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(x\^4 - 3\ x\^2 + 6\)\/\(x\^6 - 5\ x\^4 + 5\ x\^2 + 4\
\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RT = RothsteinTrager[r, x]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`1\/2\ \[ImaginaryI]\ \(log(
          x\^3 + \[ImaginaryI]\ x\^2 - 3\ x - 2\ \[ImaginaryI])\) - 
      1\/2\ \[ImaginaryI]\ \(log(
          x\^3 - \[ImaginaryI]\ x\^2 - 3\ x + 2\ \[ImaginaryI])\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[RT, {x, \(-3\), 3}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309159 0.0938219 [
[.02381 .29666 -6 -9 ]
[.02381 .29666 6 0 ]
[.18254 .29666 -6 -9 ]
[.18254 .29666 6 0 ]
[.34127 .29666 -6 -9 ]
[.34127 .29666 6 0 ]
[.65873 .29666 -3 -9 ]
[.65873 .29666 3 0 ]
[.81746 .29666 -3 -9 ]
[.81746 .29666 3 0 ]
[.97619 .29666 -3 -9 ]
[.97619 .29666 3 0 ]
[.4875 .02769 -12 -4.5 ]
[.4875 .02769 0 4.5 ]
[.4875 .12152 -12 -4.5 ]
[.4875 .12152 0 4.5 ]
[.4875 .21534 -12 -4.5 ]
[.4875 .21534 0 4.5 ]
[.4875 .40298 -6 -4.5 ]
[.4875 .40298 0 4.5 ]
[.4875 .4968 -6 -4.5 ]
[.4875 .4968 0 4.5 ]
[.4875 .59062 -6 -4.5 ]
[.4875 .59062 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30916 m
.02381 .31541 L
s
[(-3)] .02381 .29666 0 1 Mshowa
.18254 .30916 m
.18254 .31541 L
s
[(-2)] .18254 .29666 0 1 Mshowa
.34127 .30916 m
.34127 .31541 L
s
[(-1)] .34127 .29666 0 1 Mshowa
.65873 .30916 m
.65873 .31541 L
s
[(1)] .65873 .29666 0 1 Mshowa
.81746 .30916 m
.81746 .31541 L
s
[(2)] .81746 .29666 0 1 Mshowa
.97619 .30916 m
.97619 .31541 L
s
[(3)] .97619 .29666 0 1 Mshowa
.125 Mabswid
.05556 .30916 m
.05556 .31291 L
s
.0873 .30916 m
.0873 .31291 L
s
.11905 .30916 m
.11905 .31291 L
s
.15079 .30916 m
.15079 .31291 L
s
.21429 .30916 m
.21429 .31291 L
s
.24603 .30916 m
.24603 .31291 L
s
.27778 .30916 m
.27778 .31291 L
s
.30952 .30916 m
.30952 .31291 L
s
.37302 .30916 m
.37302 .31291 L
s
.40476 .30916 m
.40476 .31291 L
s
.43651 .30916 m
.43651 .31291 L
s
.46825 .30916 m
.46825 .31291 L
s
.53175 .30916 m
.53175 .31291 L
s
.56349 .30916 m
.56349 .31291 L
s
.59524 .30916 m
.59524 .31291 L
s
.62698 .30916 m
.62698 .31291 L
s
.69048 .30916 m
.69048 .31291 L
s
.72222 .30916 m
.72222 .31291 L
s
.75397 .30916 m
.75397 .31291 L
s
.78571 .30916 m
.78571 .31291 L
s
.84921 .30916 m
.84921 .31291 L
s
.88095 .30916 m
.88095 .31291 L
s
.9127 .30916 m
.9127 .31291 L
s
.94444 .30916 m
.94444 .31291 L
s
.25 Mabswid
0 .30916 m
1 .30916 L
s
.5 .02769 m
.50625 .02769 L
s
[(-3)] .4875 .02769 1 0 Mshowa
.5 .12152 m
.50625 .12152 L
s
[(-2)] .4875 .12152 1 0 Mshowa
.5 .21534 m
.50625 .21534 L
s
[(-1)] .4875 .21534 1 0 Mshowa
.5 .40298 m
.50625 .40298 L
s
[(1)] .4875 .40298 1 0 Mshowa
.5 .4968 m
.50625 .4968 L
s
[(2)] .4875 .4968 1 0 Mshowa
.5 .59062 m
.50625 .59062 L
s
[(3)] .4875 .59062 1 0 Mshowa
.125 Mabswid
.5 .04646 m
.50375 .04646 L
s
.5 .06522 m
.50375 .06522 L
s
.5 .08399 m
.50375 .08399 L
s
.5 .10275 m
.50375 .10275 L
s
.5 .14028 m
.50375 .14028 L
s
.5 .15904 m
.50375 .15904 L
s
.5 .17781 m
.50375 .17781 L
s
.5 .19657 m
.50375 .19657 L
s
.5 .2341 m
.50375 .2341 L
s
.5 .25287 m
.50375 .25287 L
s
.5 .27163 m
.50375 .27163 L
s
.5 .29039 m
.50375 .29039 L
s
.5 .32792 m
.50375 .32792 L
s
.5 .34669 m
.50375 .34669 L
s
.5 .36545 m
.50375 .36545 L
s
.5 .38422 m
.50375 .38422 L
s
.5 .42175 m
.50375 .42175 L
s
.5 .44051 m
.50375 .44051 L
s
.5 .45927 m
.50375 .45927 L
s
.5 .47804 m
.50375 .47804 L
s
.5 .51557 m
.50375 .51557 L
s
.5 .53433 m
.50375 .53433 L
s
.5 .5531 m
.50375 .5531 L
s
.5 .57186 m
.50375 .57186 L
s
.5 .00893 m
.50375 .00893 L
s
.5 .60939 m
.50375 .60939 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04921 m
.06244 .05343 L
.08255 .05619 L
.10458 .05989 L
.12507 .06424 L
.14415 .06955 L
.15465 .07325 L
.16457 .07749 L
.17341 .08212 L
.18314 .08855 L
.19284 .09701 L
.19779 .10249 L
.20312 .10958 L
.20809 .11766 L
.21264 .12664 L
.22156 .15006 L
.24215 .23148 L
.24731 .25058 L
.25218 .26578 L
.25691 .27803 L
.26127 .2874 L
.27015 .30222 L
.27975 .31385 L
.28934 .32268 L
.29946 .33016 L
.33743 .35084 L
.37786 .37012 L
.41676 .39163 L
.45813 .4208 L
.49797 .45474 L
.5363 .4878 L
.57708 .51756 L
.61635 .54002 L
.6541 .55823 L
.67507 .56835 L
.6943 .57892 L
.71315 .59248 L
.71773 .59668 L
.72025 .59922 L
.72262 .60178 L
.72328 .60252 L
.72397 .60332 L
.72474 .01472 L
.72544 .01556 L
.72799 .01881 L
.73299 .02603 L
.74243 .044 L
.74772 .05751 L
.75256 .07257 L
.77088 .14652 L
Mistroke
.78009 .17851 L
.78524 .19212 L
.7899 .20215 L
.79545 .21182 L
.80066 .21916 L
.81064 .22989 L
.82043 .23758 L
.83076 .24375 L
.84924 .25177 L
.86892 .25781 L
.88727 .26208 L
.92623 .26864 L
.94751 .27135 L
.96764 .27352 L
.97619 .27436 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003o/oooool0
0ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002c
ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0HOooool00;?ooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`1Qooooo`00/oooool00ol0003oooooooooo`1>ooooo`;o
0000H_ooool00:Sooooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo04ko
oooo0_l0001Rooooo`00Z?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo00?o0000oooooooo
ool0C_ooool00ol0003oooooo`00001Qooooo`00X?ooool6o`0000Kooooo00?o0000ooooooooool0
1?ooool3o`0004kooooo00?o0000ooooool00000HOooool00:_ooooo00?oZJVYoa0@4?ooool01Ooo
ool00ol0003oooooooooo`1>ooooo`04o`000?ooooooooooo`00063ooooo002Zooooo`03oa0@4?l0
003o^[Zj00Kooooo00?o0000ooooooooool0C_ooool01?l0003oooooooooool0001Pooooo`00Zooo
ool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo04kooooo00Go0000oooooooooooooooo
o`00001Oooooo`00Z?ooool01Ol@413oV9RHoooooonj^[[o000000Kooooo00?o0000ooooooooool0
C_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05cooooo002Xooooo`05ojVYZOl@
413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0G?ooool00;?ooooo00?o0000ooooooooool0C_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo05_ooooo002cooooo`;o0000Coooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo05_ooooo0008ooooo`So0000Xoooool00ol0003oooooooooo`1>oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0F_ooool0013ooooo2ol0002Hooooo`03
o`000?oooooooooo04kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Jooooo`00
6oooool5o`0009?ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo05[ooooo000Pooooo`Co0000Soooool00ol0003oooooooooo`1>ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0FOooool002Cooooo1_l00029ooooo`03o`000?oooooo
oooo04kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Iooooo`00:_ooool6o`00
08?ooooo0_l0001?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0FOooool0033o
oooo0ol00020ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Hooooo`00<oooool4o`0007cooooo00?o0000ooooooooool0C_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo05Sooooo000gooooo`;o0000N_ooool00ol0003ooooooooo
o`1>ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0F?ooool003Wooooo0_l0001h
ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1H
ooooo`00>oooool2o`0007Kooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo05Sooooo000mooooo`03o`000?oooooooooo07?ooooo00?o0000oooooooo
ool0C_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Oooooo000nooooo`;o0000
Loooool2o`0004oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Gooooo`00@?oo
ool2o`00077ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo05Oooooo0012ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0C_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Oooooo0013ooooo`03o`000?oooooooooo
06gooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
05Kooooo0014ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0C_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo05Kooooo0015ooooo`03o`000?oooooooooo06_ooooo
00?o0000ooooooooool0C_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05Kooooo
0016ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0C_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo05Kooooo0017ooooo`03o`000?oooooooooo06Wooooo0_l0001?
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0EOooool004Sooooo00?o0000oooo
ooooool0J?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0EOooool004Wooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`1>ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0EOooool004Wooooo00?o0000ooooooooool0
Ioooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
E?ooool004[ooooo00?o0000ooooooooool0Foooool5o`0000Kooooo00?o0000ooooooooool0C_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Cooooo001:ooooo`03o`000?oooooo
oooo05_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo04kooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1Dooooo`00B_ooool00ol0003oooooooooo`1C
ooooo`Ko00000oooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo04kooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`1Dooooo`00Boooool00ol0003oooooooooo`1Loooo
o`03oiRHV?lQ8B7ok^k^00Kooooo0ol0001>ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0Doooool004cooooo00?o0000ooooooooool0G?ooool00omgMgOoIVIVooooo`05ooooo`03
o`000?oooooooooo04kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Cooooo`00
C?ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
C_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05?ooooo001=ooooo`03o`000?oo
oooooooo05Sooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo04kooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`1Cooooo`00COooool00ol0003ooooooooo
o`1Hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1>ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0D_ooool004gooooo00?o0000ooooooooool0Hooo
ool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0D_oo
ool004kooooo00?o0000ooooooooool0H_ooool2o`0004oooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`1Booooo`00C_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo
04kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Booooo`00C_ooool00ol0003o
ooooooooo`1Rooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`1Aooooo`00Coooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo04kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Aooooo`00Coooool00ol0003ooooooooo
o`1Qooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`1Aooooo`00Coooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo04kooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`1Aooooo`00Coooool00ol0003oooooooooo`1Qoooo
o`03o`000?oooooooooo04kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1@oooo
o`00D?ooool00ol0003oooooooooo`1Pooooo`;o0000Coooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo053ooooo001@ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0
C_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo053ooooo001@ooooo`03o`000?oo
oooooooo063ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo04oooooo001Aooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0C_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04oooooo001Aooooo`03o`000?oooooooooo
05oooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
04oooooo001Aooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0C_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo04oooooo001Aooooo`03o`000?oooooooooo05oooooo
00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04kooooo
001Booooo`03o`000?oooooooooo05kooooo0_l0001?ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0C_ooool005;ooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`1>
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0C_ooool005;ooooo00?o0000oooo
ooooool0G_ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0COooool005;ooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`1>ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0COooool005?ooooo00?o0000ooooooooool0
GOooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
COooool005?ooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`1>ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0C?ooool005?ooooo00?o0000ooooooooool0GOooool0
0ol0003oooooooooo`1>ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0C?ooool0
05Cooooo00?o0000ooooooooool0G?ooool2o`0004oooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`1;ooooo`00E?ooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo04ko
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1;ooooo`00E?ooool00ol0003ooooo
ooooo`1Looooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`1:ooooo`00E?ooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo04kooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`1:ooooo`00EOooool00ol0003oooooooooo`1A
ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0BOooool005Gooooo00?o0000ooooooooool0Doooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`18ooooo`00EOooool00ol0003oooooooooo`18ooooo`Ko00001Oooool00ol0003o
ooooooooo`05ooooo`?o0000C_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04So
oooo001Eooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1>ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Aoooool005Kooooo00?o
0000ooooooooool0D_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04kooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`16ooooo`00E_ooool00ol0003oooooooooo`1B
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo04Gooooo001Fooooo`03o`000?oooooooooo05;ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool0A?ooool005Oooooo00?o0000ooooooooool0Coooool00omEEEGoIVIVo`000007ooooo`03
o`000?oooooooooo04kooooo00?o0000ooooooooool06oooool2o`0004Cooooo001Gooooo`03o`00
0?oooooooooo05Wooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo047ooooo001Gooooo`03o`000?oooooooooo05Wooooo0_l0001?ooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool0@?ooool005Oooooo00?o0000ooooooooool0FOooool0
0ol0003oooooooooo`1>ooooo`03o`000?oooooooooo01oooooo0_l00010ooooo`00Eoooool00ol0
003oooooooooo`1Iooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`0mooooo`00F?ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo04ko
oooo00?o0000ooooooooool08_ooool2o`0003gooooo001Hooooo`03o`000?oooooooooo05Sooooo
00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0Tooooo`?o0000>_ooool005Sooooo00?o
0000ooooooooool0F?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo02Oooooo0_l0
000hooooo`00F?ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo04kooooo00?o0000
ooooooooool0:Oooool3o`0003Gooooo001Hooooo`03o`000?oooooooooo05Sooooo0_l0001?oooo
o`03o`000?oooooooooo02cooooo0ol0000booooo`00FOooool00ol0003oooooooooo`1Gooooo`03
o`000?oooooooooo04kooooo00?o0000ooooooooool0;oooool4o`0002kooooo001Iooooo`03o`00
0?oooooooooo05Oooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0cooooo`?o0000
:oooool005Wooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`1>ooooo`03o`000?oo
oooooooo03Kooooo1_l0000Uooooo`00F_ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooo
oooo04kooooo00?o0000ooooooooool0??ooool7o`0001kooooo001Jooooo`03o`000?oooooooooo
05Kooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`13ooooo`Oo00005oooool000Wo
oooo00GoV9RHoa0@4?l0003o<S8bolc<c00dooooo`Go00005?ooool00ol0003oooooooooo`0Noooo
o`Co000000?o410@ooooooooool0<?ooool2o`0003Gooooo1?l000000ol@413oooooooooo`0Coooo
o`03o`000?oooooooooo01_ooooo1Ol0000Zooooo`Oo00000oooool01OnHV9So410@o`000?lb<S;o
c<c<00Sooooo0009ooooo`05oa0@4?nj^[[oooooogMgMolb<S80=?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A401Cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Kooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@0<Oooool7o`000003oc8b<_oooooooooo00Kooooo00000ooooooo0000o`00
0004o`0000Kooooo00?o0000ooooooooool0:_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h05Ooo
ool00ol0003oooooooooo`0Eooooo`Ko00001Oooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Looooo`03oiRHV?lQ
8B7ok^k^03Wooooo00?o0000ooooooooool01_ooool000cooooo00?oZJVYoa0@4?ooool0=Oooool0
0onHV9So8B4Qonk^kP0Eooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool07Oooool0
0onHV9So8B4Qonk^kP0gooooo`03ojVYZOl@413ooooo00Oooooo000;ooooo`03oa0@4?l0003o^[Zj
03Oooooo00?oMgMgofIVI_ooool05?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
01kooooo00?oMgMgofIVI_ooool0=Oooool00ol@413o0000okZj^P08ooooo`003?ooool00onj^[[o
8B4Qooooo`0gooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0booooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo03Gooooo00?o^[Zjob4Q8Oooool01oooool000Wooooo
00Go410@oiRHV?oooooo^[Zjo`00000dooooo`05o`000?nj^[[ooooooiRHV?l@41005_ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo01_ooooo00Go0000okZj^_ooooooV9RHoa0@400d
ooooo`05oa0@4?nHV9SooooookZj^_l000002?ooool000Wooooo00GoZJVYoa0@4?l0003o410@ojVY
Z@0dooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`05_ooool00ol0003oooooooooo`0Looooo`03oeEE
EOmVIVKo000003Cooooo0_l0000eooooo`03oeEEEOmVIVKo000001Oooooo00?o0000ooooooooool0
6oooool01OnHV9So410@o`000?lQ8B7oc<c<03Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@08oooo
o`00G_ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo04kooooo00?o0000oooooooo
ool0HOooool005oooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`1>ooooo`03o`00
0?oooooooooo067ooooo001Pooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0C_oo
ool00ol0003oooooooooo`1Qooooo`00HOooool00ol0003oooooooooo`1?ooooo`03o`000?oooooo
oooo04kooooo00?o0000ooooooooool0HOooool0067ooooo00?o0000ooooooooool0Coooool00ol0
003oooooooooo`1>ooooo`03o`000?oooooooooo067ooooo001Rooooo`03o`000?oooooooooo04ko
oooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1Qooooo`00ool0001Xo`00007ooooo
0008ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool08?ooool2o`0001Cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo00Oooooo001Vooooo`03o`000?oooooooooo04[ooooo00?o0000oooo
ooooool0COooool00ol0003oooooooooo`1Rooooo`00Ioooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo04gooooo00?o0000ooooooooool0H_ooool006Sooooo0_l00019ooooo`03o`00
0?oooooooooo04gooooo00?o0000ooooooooool0H_ooool006[ooooo00?o0000ooooooooool0A_oo
ool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo06;ooooo001[ooooo`;o0000A_ooool2
o`0004kooooo00?o0000ooooooooool0H_ooool006gooooo0_l00014ooooo`03o`000?oooooooooo
04gooooo00?o0000ooooooooool0H_ooool006oooooo00?o0000ooooooooool0@Oooool00ol0003o
ooooooooo`1=ooooo`03o`000?oooooooooo06;ooooo001`ooooo`;o0000@Oooool00ol0003ooooo
ooooo`1=ooooo`03o`000?oooooooooo06;ooooo001booooo`;o0000?oooool00ol0003ooooooooo
o`1=ooooo`03o`000?oooooooooo06;ooooo001dooooo`;o0000?Oooool00ol0003oooooooooo`1=
ooooo`03o`000?oooooooooo06;ooooo001fooooo`03o`000?oooooooooo03[ooooo0_l0001>oooo
o`03o`000?oooooooooo06;ooooo001gooooo`;o0000>_ooool00ol0003oooooooooo`1=ooooo`03
o`000?oooooooooo06;ooooo001iooooo`;o0000>?ooool00ol0003oooooooooo`1=ooooo`03o`00
0?oooooooooo06;ooooo001kooooo`;o0000=_ooool00ol0003oooooooooo`1=ooooo`03o`000?oo
oooooooo06;ooooo001mooooo`;o0000=?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooo
oooo06;ooooo001oooooo`;o0000<_ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo
06;ooooo0021ooooo`;o0000<?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo06;o
oooo0023ooooo`;o0000;_ooool2o`0004kooooo00?o0000ooooooooool0H_ooool008Gooooo0_l0
000/ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0H_ooool008Oooooo0_l0000Z
ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0H_ooool008Wooooo0_l0000Xoooo
o`03o`000?oooooooooo04gooooo00?o0000ooooooooool0H_ooool008_ooooo0_l0000Vooooo`03
o`000?oooooooooo04gooooo00?o0000ooooooooool0H_ooool008gooooo0_l0000Tooooo`03o`00
0?oooooooooo04gooooo00?o0000ooooooooool0H_ooool008oooooo0_l0000Rooooo`03o`000?oo
oooooooo04gooooo00?o0000ooooooooool0H_ooool0097ooooo0_l0000Pooooo`;o0000C_ooool0
0ol0003oooooooooo`1Rooooo`00Toooool2o`0001kooooo00?o0000ooooooooool0COooool00ol0
003oooooooooo`1Rooooo`00UOooool2o`0001cooooo00?o0000ooooooooool0COooool00ol0003o
ooooooooo`1Rooooo`00Uoooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04gooooo
00?o0000ooooooooool0H_ooool009Sooooo00?o0000ooooooooool03_ooool4o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1Rooooo`00VOooool2
o`00013ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooo
oooo06;ooooo002Kooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool3o`00
04gooooo00?o0000ooooooooool0H_ooool009cooooo0_l0000=ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1Rooooo`00W_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0COooool00ol0003ooooo
ooooo`1Rooooo`00Woooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0COooool00ol0003oooooooooo`1Rooooo`00X?ooool2o`0000Wooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo06;ooooo002Roooo
o`03o`000?oooooooooo00Cooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`1=oooo
o`03o`000?oooooooooo06;ooooo002Sooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool0COooool00ol0003oooooooooo`1Rooooo`00Y?ooool2o`0000gooooo0_l0001>ooooo`03o`00
0?oooooooooo06;ooooo002Vooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0COoo
ool00ol0003oooooooooo`1Rooooo`00Yoooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo04gooooo00?o0000ooooooooool0H_ooool00:Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`1=ooooo`03o`000?oooooooooo06;ooooo002Yooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1Rooooo`00Z_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0H_ooool00:_ooooo0_l0
0006ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0H_ooool00:gooooo00?o0000
ooooooooool00oooool2o`0004kooooo00?o0000ooooooooool0H_ooool00:kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo06;ooooo002_ooooo`05
o`000?ooooooooooooooool00000Coooool00ol0003oooooooooo`1Rooooo`00/?ooool01?l0003o
ooooooooool0001?ooooo`03o`000?oooooooooo06;ooooo002aooooo`03o`000?oooooo000004oo
oooo00?o0000ooooooooool0H_ooool00;;ooooo0_l0001?ooooo`03o`000?oooooooooo06;ooooo
002cooooo`;o0000C_ooool00ol0003oooooooooo`1Rooooo`00/oooool3o`0004gooooo00?o0000
ooooooooool0H_ooool00;?ooooo00Co0000oooooooooooo0000C?ooool00ol0003oooooooooo`1R
ooooo`00/oooool01Ol0003ooooooooooooooooo000004_ooooo00?o0000ooooooooool0H_ooool0
0;?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo
06;ooooo002cooooo`03o`000?oooooooooo00?ooooo0_l00018ooooo`03o`000?oooooooooo06;o
oooo002cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`1Rooooo`00/oooool2o`0000Oooooo00?o0000ooooooooool0A?ooool00ol0003ooooooooo
o`1Rooooo`00/oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04?ooooo00?o0000
ooooooooool0H_ooool00;?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`12oooo
o`03o`000?oooooooooo06;ooooo002cooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0@Oooool00ol0003oooooooooo`1Rooooo`00/oooool00ol0003oooooooooo`0:ooooo`;o0000
@Oooool00ol0003oooooooooo`1Rooooo`00Z?ooool5o`0000Kooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo06;ooooo002Xooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool0H_ooool00:Wooooo00?oV9RHob4Q8Oo^k^h01oooool3o`0000kooooo0_l0000m
ooooo`03o`000?oooooooooo06;ooooo002Zooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo06;ooooo002[ooooo`03
ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool04Oooool2o`0003[ooooo00?o0000oooooooo
ool0H_ooool00:cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool0H_ooool00:Sooooo00Go0000okZj^_ooooooV9RH
oa0@4006ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`1Rooooo`00Z?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0
5Oooool2o`0003Kooooo00?o0000ooooooooool0H_ooool00;?ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo06;ooooo002cooooo`;o00006Oooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo06;ooooo002cooooo`03o`000?oooooooooo
01Wooooo0_l0000booooo`03o`000?oooooooooo06;ooooo002cooooo`03o`000?oooooooooo01_o
oooo0_l0000`ooooo`03o`000?oooooooooo06;ooooo002cooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Rooooo`00/oooool00ol0003ooooooooo
o`0Nooooo`;o0000;Oooool00ol0003oooooooooo`1Rooooo`00/oooool00ol0003oooooooooo`0P
ooooo`;o0000:oooool00ol0003oooooooooo`1Rooooo`00/oooool00ol0003oooooooooo`0Roooo
o`;o0000:Oooool00ol0003oooooooooo`1Rooooo`00/oooool2o`0002Gooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`1Rooooo`00/oooool00ol0003oooooooooo`0Uooooo`;o0000
9_ooool00ol0003oooooooooo`1Rooooo`00/oooool00ol0003oooooooooo`0Wooooo`;o00009?oo
ool00ol0003oooooooooo`1Rooooo`00/oooool00ol0003oooooooooo`0Yooooo`;o00008_ooool0
0ol0003oooooooooo`1Rooooo`00/oooool00ol0003oooooooooo`0[ooooo`;o00008?ooool00ol0
003oooooooooo`1Rooooo`00/oooool00ol0003oooooooooo`0]ooooo`?o00007Oooool00ol0003o
ooooooooo`1Rooooo`00/oooool2o`00037ooooo0_l0000Kooooo`03o`000?oooooooooo06;ooooo
002cooooo`03o`000?oooooooooo03;ooooo0_l0000Iooooo`03o`000?oooooooooo06;ooooo002c
ooooo`03o`000?oooooooooo03Cooooo0_l0000Gooooo`03o`000?oooooooooo06;ooooo002coooo
o`03o`000?oooooooooo03Kooooo0_l0000Eooooo`03o`000?oooooooooo06;ooooo002cooooo`03
o`000?oooooooooo03Sooooo0_l0000Cooooo`03o`000?oooooooooo06;ooooo002cooooo`03o`00
0?oooooooooo03[ooooo0_l0000Aooooo`03o`000?oooooooooo06;ooooo002cooooo`03o`000?oo
oooooooo03cooooo0_l0000?ooooo`03o`000?oooooooooo06;ooooo002cooooo`;o0000?oooool3
o`0000cooooo00?o0000ooooooooool0H_ooool00;?ooooo00?o0000ooooooooool0@Oooool2o`00
00[ooooo00?o0000ooooooooool0H_ooool00;?ooooo00?o0000ooooooooool0@oooool2o`0000So
oooo00?o0000ooooooooool0H_ooool00;?ooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo06;ooooo002Xooooo`05oiRHV?l@413o0000oc8b<_o<c<`0
1_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
H_ooool00:Sooooo00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo04Oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`1Rooooo`00[?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`1Rooooo`00Zoooool00onYZJWo410@ooooo`05ooooo`?o0000BOooool01Ol0003ooooooooooooo
oooo000006Cooooo002Zooooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000ooooooooool0B_ooool0
1?l0003oooooooooool0001Tooooo`00Zoooool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooo
oooo04_ooooo00?o0000ooooool00000I?ooool00:Sooooo00Go410@oiRHV?oooooo^[Zjo`000006
ooooo`03o`000?oooooooooo04cooooo0_l0001Tooooo`00Z?ooool01OnYZJWo410@o`000?l@413o
ZJVY00Kooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1Rooooo`00/oooool00ol0
003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.15712, -3.2952, \
0.0219855, 0.0371956}}],

Cell[BoxData[
    FormBox[
      TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
        False,
        Editable->False], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(int = 
      ArcTan[ComplexExpand[Re[x\^3 + \[ImaginaryI]\ x\^2 - 3\ x - 2\ \
\[ImaginaryI]]]\/ComplexExpand[Im[x\^3 + \[ImaginaryI]\ x\^2 - 3\ x - 2\ \
\[ImaginaryI]]]]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(tan\^\(-1\)\)(\(x\^3 - 3\ x\)\/\(x\^2 - 2\))\)], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[int - RT, {x, \(-3\), 3}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.187358 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 .02798 -24 -4.5 ]
[.4875 .02798 0 4.5 ]
[.4875 .12166 -12 -4.5 ]
[.4875 .12166 0 4.5 ]
[.4875 .21534 -24 -4.5 ]
[.4875 .21534 0 4.5 ]
[.4875 .4027 -18 -4.5 ]
[.4875 .4027 0 4.5 ]
[.4875 .49638 -6 -4.5 ]
[.4875 .49638 0 4.5 ]
[.4875 .59005 -18 -4.5 ]
[.4875 .59005 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 .02798 m
.50625 .02798 L
s
[(-1.5)] .4875 .02798 1 0 Mshowa
.5 .12166 m
.50625 .12166 L
s
[(-1)] .4875 .12166 1 0 Mshowa
.5 .21534 m
.50625 .21534 L
s
[(-0.5)] .4875 .21534 1 0 Mshowa
.5 .4027 m
.50625 .4027 L
s
[(0.5)] .4875 .4027 1 0 Mshowa
.5 .49638 m
.50625 .49638 L
s
[(1)] .4875 .49638 1 0 Mshowa
.5 .59005 m
.50625 .59005 L
s
[(1.5)] .4875 .59005 1 0 Mshowa
.125 Mabswid
.5 .04672 m
.50375 .04672 L
s
.5 .06545 m
.50375 .06545 L
s
.5 .08419 m
.50375 .08419 L
s
.5 .10292 m
.50375 .10292 L
s
.5 .14039 m
.50375 .14039 L
s
.5 .15913 m
.50375 .15913 L
s
.5 .17787 m
.50375 .17787 L
s
.5 .1966 m
.50375 .1966 L
s
.5 .23407 m
.50375 .23407 L
s
.5 .25281 m
.50375 .25281 L
s
.5 .27155 m
.50375 .27155 L
s
.5 .29028 m
.50375 .29028 L
s
.5 .32775 m
.50375 .32775 L
s
.5 .34649 m
.50375 .34649 L
s
.5 .36522 m
.50375 .36522 L
s
.5 .38396 m
.50375 .38396 L
s
.5 .42143 m
.50375 .42143 L
s
.5 .44017 m
.50375 .44017 L
s
.5 .4589 m
.50375 .4589 L
s
.5 .47764 m
.50375 .47764 L
s
.5 .51511 m
.50375 .51511 L
s
.5 .53385 m
.50375 .53385 L
s
.5 .55258 m
.50375 .55258 L
s
.5 .57132 m
.50375 .57132 L
s
.5 .00924 m
.50375 .00924 L
s
.5 .60879 m
.50375 .60879 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.06244 .60332 L
.10458 .60332 L
.12507 .60332 L
.14415 .60332 L
.16254 .60332 L
.18221 .60332 L
.22365 .60332 L
.24442 .60332 L
.25354 .60332 L
.26358 .60332 L
.26822 .60332 L
.27078 .60332 L
.27321 .60332 L
.2743 .60332 L
.27546 .60332 L
.27674 .01472 L
.27792 .01472 L
.28223 .01472 L
.302 .01472 L
.34358 .01472 L
.38365 .01472 L
.4222 .01472 L
.4632 .01472 L
.50269 .01472 L
.54066 .01472 L
.58108 .01472 L
.61999 .01472 L
.66135 .01472 L
.68205 .01472 L
.7012 .01472 L
.71078 .01472 L
.71978 .01472 L
.72198 .01472 L
.72318 .01472 L
.7243 .01472 L
.72551 .60332 L
.72615 .60332 L
.72684 .60332 L
.72917 .60332 L
.73953 .60332 L
.78103 .60332 L
.82101 .60332 L
.85947 .60332 L
.90039 .60332 L
.9398 .60332 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003o/oooool0
0ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo001S
oooooj7o0000I?ooool006?ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1=oooo
o`03o`000?oooooooooo06;ooooo001Sooooo`03o`000?oooooooooo04gooooo00?o0000oooooooo
ool0COooool00ol0003oooooooooo`1Rooooo`00Hoooool00ol0003oooooooooo`0cooooo`Co0000
00?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo04gooooo00?o0000ooooooooool0H_ooool006?ooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo04gooooo00?o0000ooooooooool0H_ooool006?ooooo00?o0000ooooooooool0:_oo
ool6o`0000Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`?o0000COoo
ool00ol0003oooooooooo`1Rooooo`00Hoooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo00kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooo
oooo06;ooooo001Sooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool02oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1R
ooooo`00Hoooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo06;ooooo001Sooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo04gooooo00?o0000ooooooooool0H_ooool006?ooooo00?o0000ooooooooool0
<oooool00omEEEGoIVIVo`00000=ooooo`Co00001_ooool00ol0003oooooooooo`1=ooooo`03o`00
0?oooooooooo06;ooooo001Sooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0COoo
ool00ol0003oooooooooo`1Rooooo`00Hoooool00ol0003oooooooooo`1=ooooo`;o0000C_ooool0
0ol0003oooooooooo`1Rooooo`00Hoooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo
04gooooo00?o0000ooooooooool0H_ooool006?ooooo00?o0000ooooooooool0COooool00ol0003o
ooooooooo`1=ooooo`03o`000?oooooooooo06;ooooo001Sooooo`03o`000?oooooooooo04gooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`1Rooooo`00Hoooool00ol0003ooooooooo
o`1=ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0H_ooool006?ooooo00?o0000
ooooooooool0COooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo06;ooooo001Soooo
o`03o`000?oooooooooo04gooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1Roooo
o`00Hoooool00ol0003oooooooooo`1=ooooo`;o0000C_ooool00ol0003oooooooooo`1Rooooo`00
Hoooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0
H_ooool006?ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1=ooooo`03o`000?oo
oooooooo06;ooooo001Sooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0COooool0
0ol0003oooooooooo`1Rooooo`00Hoooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo
04gooooo00?o0000ooooooooool0H_ooool006?ooooo00?o0000ooooooooool0COooool00ol0003o
ooooooooo`1=ooooo`03o`000?oooooooooo06;ooooo001Sooooo`03o`000?oooooooooo04gooooo
0_l0001>ooooo`03o`000?oooooooooo06;ooooo001Sooooo`03o`000?oooooooooo04gooooo00?o
0000ooooooooool0COooool00ol0003oooooooooo`1Rooooo`00Hoooool00ol0003oooooooooo`1=
ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0H_ooool006?ooooo00?o0000oooo
ooooool0COooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo06;ooooo001Sooooo`03
o`000?oooooooooo04gooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1Rooooo`00
Hoooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0
H_ooool006?ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1=ooooo`03o`000?oo
oooooooo06;ooooo001Sooooo`03o`000?oooooooooo04gooooo0_l0001>ooooo`03o`000?oooooo
oooo06;ooooo001Sooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0COooool00ol0
003oooooooooo`1Rooooo`00Hoooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo04go
oooo00?o0000ooooooooool0H_ooool006?ooooo00?o0000ooooooooool0COooool00ol0003ooooo
ooooo`1=ooooo`03o`000?oooooooooo06;ooooo001Sooooo`03o`000?oooooooooo04?ooooo1?l0
00000ol@413oooooooooo`03ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0H_oo
ool006?ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo04gooooo00?o0000ooooooooool0H_ooool006?ooooo00?o0000ooooooooool0>_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo
06;ooooo001Sooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool01Oooool3o`0004go
oooo00?o0000ooooooooool0H_ooool006?ooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0H_ooool006?ooooo00?o
0000ooooooooool0AOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04gooooo00?o
0000ooooooooool0H_ooool006?ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0H_ooool006?ooooo00?o0000oooo
ooooool0@oooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo04gooooo00?o0000oooo
ooooool0H_ooool006?ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1=ooooo`03
o`000?oooooooooo06;ooooo001Sooooo`03o`000?oooooooooo04gooooo0_l0001>ooooo`03o`00
0?oooooooooo06;ooooo001Sooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0COoo
ool00ol0003oooooooooo`1Rooooo`00Hoooool00ol0003oooooooooo`1=ooooo`03o`000?oooooo
oooo04gooooo00?o0000ooooooooool0H_ooool006?ooooo00?o0000ooooooooool0COooool00ol0
003oooooooooo`1=ooooo`03o`000?oooooooooo06;ooooo001Sooooo`03o`000?oooooooooo04go
oooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1Rooooo`00Hoooool00ol0003ooooo
ooooo`1=ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0H_ooool006?ooooo00?o
0000ooooooooool0COooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo06;ooooo001S
ooooo`03o`000?oooooooooo04gooooo0_l0001>ooooo`03o`000?oooooooooo06;ooooo001Soooo
o`03o`000?oooooooooo04gooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1Roooo
o`00Hoooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo04gooooo00?o0000oooooooo
ool0H_ooool006?ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1=ooooo`03o`00
0?oooooooooo06;ooooo001Sooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0COoo
ool00ol0003oooooooooo`1Rooooo`00Hoooool00ol0003oooooooooo`1=ooooo`03o`000?oooooo
oooo04gooooo00?o0000ooooooooool0H_ooool006?ooooo00?o0000ooooooooool0COooool00ol0
003oooooooooo`1=ooooo`03o`000?oooooooooo06;ooooo001Sooooo`03o`000?oooooooooo04go
oooo0_l0001>ooooo`03o`000?oooooooooo06;ooooo001Sooooo`03o`000?oooooooooo04gooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`1Rooooo`00Hoooool00ol0003ooooooooo
o`1=ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0H_ooool006?ooooo00?o0000
ooooooooool0COooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo06;ooooo001Soooo
o`03o`000?oooooooooo04gooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1Roooo
o`00Hoooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo04gooooo00?o0000oooooooo
ool0H_ooool006?ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1=ooooo`03o`00
0?oooooooooo06;ooooo001Sooooo`03o`000?oooooooooo04gooooo0_l0001>ooooo`03o`000?oo
oooooooo06;ooooo001Sooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0COooool0
0ol0003oooooooooo`1Rooooo`00Hoooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo
04gooooo00?o0000ooooooooool0H_ooool006?ooooo00?o0000ooooooooool0COooool00ol0003o
ooooooooo`1=ooooo`03o`000?oooooooooo06;ooooo001Sooooo`03o`000?oooooooooo03;ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1Rooooo`00Hoooool00ol0003o
ooooooooo`0booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo06;ooooo001Sooooo`03
o`000?oooooooooo02[ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`03ooooo`?o0000COooool00ol0003oooooooooo`1Rooooo`00Hoooool00ol0003o
ooooooooo`0booooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo04gooooo00?o0000ooooooooool0H_ooool006?ooooo00?o0000oooooooo
ool0<_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0H_ooool006?ooooo00?o0000oooo
ooooool0<_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1=ooooo`03o`000?oooooooooo06;ooooo001Sooooo`03o`000?oooooooooo
03;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0COooool00ol0003oooooooooo`1Rooooo`00Hoooool00ol0003oooooooooo`0boooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0COooool0
0ol0003oooooooooo`1Rooooo`00Hoooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo
04gooooo00?o0000ooooooooool0H_ooool006?ooooo00?o0000ooooooooool0COooool2o`0004ko
oooo00?o0000ooooooooool0H_ooool006?ooooo00?o0000ooooooooool0COooool00ol0003ooooo
ooooo`1=ooooo`03o`000?oooooooooo06;ooooo001Sooooo`03o`000?oooooooooo04gooooo00?o
0000ooooooooool0COooool00ol0003oooooooooo`1Rooooo`00Hoooool00ol0003oooooooooo`1=
ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0H_ooool006?ooooo00?o0000oooo
ooooool0COooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo06;ooooo001Sooooo`03
o`000?oooooooooo04gooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1Rooooo`00
Hoooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0
H_ooool006?ooooo00?o0000ooooooooool0COooool2o`0004kooooo00?o0000ooooooooool0H_oo
ool006?ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1=ooooo`03o`000?oooooo
oooo06;ooooo001Sooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0COooool00ol0
003oooooooooo`1Rooooo`00Hoooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo04go
oooo00?o0000ooooooooool0H_ooool006?ooooo00?o0000ooooooooool0COooool00ol0003ooooo
ooooo`1=ooooo`03o`000?oooooooooo06;ooooo001Sooooo`03o`000?oooooooooo04gooooo00?o
0000ooooooooool0COooool00ol0003oooooooooo`1Rooooo`002Oooool01OnHV9So410@o`000?lb
<S;oc<c<03Cooooo1Ol0000Looooo`03o`000?oooooooooo01Kooooo1?l000000ol@413ooooooooo
o`0`ooooo`;o0000=Oooool4o`000003oa0@4?oooooooooo01;ooooo00?o0000ooooooooool07?oo
ool5o`0003Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c008ooooo`002Oooool01Ol@413o^[Zjoooo
oomgMgOo<S8b03Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Looooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool07?ooool01OnHV9So8B4Qonk^k_ooooooA4A403Cooooo00Go410@okZj
^_ooooooMgMgoc8b<P08ooooo`0000?oooooo`000?l000001?l00006ooooo`03o`000?oooooooooo
02[ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^01gooooo00?o0000ooooooooool03Oooool6o`00
00Gooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool07Oooool00onHV9So8B4Qonk^kP0iooooo`03o`000?oooooooooo
00Kooooo000<ooooo`03ojVYZOl@413ooooo03Gooooo00?oV9RHob4Q8Oo^k^h07?ooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo01kooooo00?oV9RHob4Q8Oo^k^h0=oooool00onYZJWo
410@ooooo`07ooooo`002oooool00ol@413o0000okZj^P0gooooo`03ogMgMomVIVKooooo01_ooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo03Kooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Oooooo`03ogMgMomVIVKooooo03Gooooo
00?o410@o`000?nj^[X02?ooool000cooooo00?o^[Zjob4Q8Oooool0=oooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0eooooo`03okZj^_lQ8B7ooooo00Oooooo0009ooooo`05oa0@4?nHV9SooooookZj^_l00000=?oo
ool01Ol0003o^[ZjoooooonHV9So410@01cooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0Looooo`05o`000?nj^[[ooooooiRHV?l@4100=?ooool01Ol@413oV9RHoooooonj^[[o0000
00Sooooo0009ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=?ooool01OnHV9So410@o`000?lQ8B7o
c<c<01cooooo00?o0000ooooooooool05_ooool00omEEEGoIVIVo`00000dooooo`;o0000=Oooool0
0omEEEGoIVIVo`00000Fooooo`03o`000?oooooooooo01cooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00dooooo`05ojVYZOl@413o0000oa0@4?nYZJT02?ooool006?ooooo00?o0000ooooooooool0COoo
ool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo06;ooooo001Sooooo`03o`000?oooooo
oooo04gooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1Rooooo`00Hoooool00ol0
003oooooooooo`1=ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0H_ooool006?o
oooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo06;o
oooo001Sooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0COooool00ol0003ooooo
ooooo`1Rooooo`00Hoooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo04gooooo00?o
0000ooooooooool0H_ooool00?oo0000J?l00001ooooo`002?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09oooo
o`;o00002Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo0008ooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`07ooooo`00
Hoooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0
HOooool006?ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1>ooooo`03o`000?oo
oooooooo067ooooo001Sooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0C_ooool0
0ol0003oooooooooo`1Qooooo`00Hoooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo
04kooooo00?o0000ooooooooool0HOooool006?ooooo00?o0000ooooooooool0COooool2o`0004oo
oooo00?o0000ooooooooool0HOooool006?ooooo00?o0000ooooooooool0COooool00ol0003ooooo
ooooo`1>ooooo`03o`000?oooooooooo067ooooo001Sooooo`03o`000?oooooooooo04gooooo00?o
0000ooooooooool0C_ooool00ol0003oooooooooo`1Qooooo`00Hoooool00ol0003oooooooooo`1=
ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0HOooool006?ooooo00?o0000oooo
ooooool0COooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo067ooooo001Sooooo`03
o`000?oooooooooo04gooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1Qooooo`00
Hoooool00ol0003oooooooooo`1=ooooo`;o0000Coooool00ol0003oooooooooo`1Qooooo`00Hooo
ool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0HOoo
ool006?ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1>ooooo`03o`000?oooooo
oooo067ooooo001Sooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0C_ooool00ol0
003oooooooooo`1Qooooo`00Hoooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo04ko
oooo00?o0000ooooooooool0HOooool006?ooooo00?o0000ooooooooool0COooool00ol0003ooooo
ooooo`1>ooooo`03o`000?oooooooooo067ooooo001Sooooo`03o`000?oooooooooo04gooooo00?o
0000ooooooooool0C_ooool00ol0003oooooooooo`1Qooooo`00Hoooool00ol0003oooooooooo`1=
ooooo`;o0000Coooool00ol0003oooooooooo`1Qooooo`00Hoooool00ol0003oooooooooo`1=oooo
o`03o`000?oooooooooo04kooooo00?o0000ooooooooool0HOooool006?ooooo00?o0000oooooooo
ool0COooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo067ooooo001Sooooo`03o`00
0?oooooooooo04gooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1Qooooo`00Hooo
ool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0HOoo
ool006?ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1>ooooo`03o`000?oooooo
oooo067ooooo001Sooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0C_ooool00ol0
003oooooooooo`1Qooooo`00Hoooool00ol0003oooooooooo`1=ooooo`;o0000Coooool00ol0003o
ooooooooo`1Qooooo`00Hoooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo04kooooo
00?o0000ooooooooool0HOooool006?ooooo00?o0000ooooooooool0COooool00ol0003ooooooooo
o`1>ooooo`03o`000?oooooooooo067ooooo001Sooooo`03o`000?oooooooooo04gooooo00?o0000
ooooooooool0C_ooool00ol0003oooooooooo`1Qooooo`00Hoooool00ol0003oooooooooo`0boooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@05ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0HOooool006?ooooo00?o0000
ooooooooool0<_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1Qooooo`00Hoooool0
0ol0003oooooooooo`0booooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`03ooooo`?o0000C_ooool00ol0003oooooooooo`1Qooooo`00Hoooool00ol0003oooooooooo`0b
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo04kooooo00?o0000ooooooooool0HOooool006?ooooo00?o0000ooooooooool0<_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo04kooooo00?o0000ooooooooool0HOooool006?ooooo00?o0000ooooooooool0<_oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`1>ooooo`03o`000?oooooooooo067ooooo001Sooooo`03o`000?oooooooooo03;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
C_ooool00ol0003oooooooooo`1Qooooo`00Hoooool00ol0003oooooooooo`0booooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0C_ooool00ol0003ooooo
ooooo`1Qooooo`00Hoooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo04kooooo00?o
0000ooooooooool0HOooool006?ooooo00?o0000ooooooooool0COooool2o`0004oooooo00?o0000
ooooooooool0HOooool006?ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1>oooo
o`03o`000?oooooooooo067ooooo001Sooooo`03o`000?oooooooooo04gooooo00?o0000oooooooo
ool0C_ooool00ol0003oooooooooo`1Qooooo`00Hoooool00ol0003oooooooooo`1=ooooo`03o`00
0?oooooooooo04kooooo00?o0000ooooooooool0HOooool006?ooooo00?o0000ooooooooool0COoo
ool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo067ooooo001Sooooo`03o`000?oooooo
oooo04gooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1Qooooo`00Hoooool00ol0
003oooooooooo`1=ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0HOooool006?o
oooo00?o0000ooooooooool0COooool2o`0004oooooo00?o0000ooooooooool0HOooool006?ooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo067ooooo
001Sooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0C_ooool00ol0003ooooooooo
o`1Qooooo`00Hoooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo04kooooo00?o0000
ooooooooool0HOooool006?ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1>oooo
o`03o`000?oooooooooo067ooooo001Sooooo`03o`000?oooooooooo04gooooo00?o0000oooooooo
ool0C_ooool00ol0003oooooooooo`1Qooooo`00Hoooool00ol0003oooooooooo`1=ooooo`;o0000
Coooool00ol0003oooooooooo`1Qooooo`00Hoooool00ol0003oooooooooo`1=ooooo`03o`000?oo
oooooooo04kooooo00?o0000ooooooooool0HOooool006?ooooo00?o0000ooooooooool0COooool0
0ol0003oooooooooo`1>ooooo`03o`000?oooooooooo067ooooo001Sooooo`03o`000?oooooooooo
04gooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1Qooooo`00Hoooool00ol0003o
ooooooooo`1=ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0HOooool006?ooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo067ooooo
001Sooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0C_ooool00ol0003ooooooooo
o`1Qooooo`00Hoooool00ol0003oooooooooo`1=ooooo`;o0000Coooool00ol0003oooooooooo`1Q
ooooo`00Hoooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo04kooooo00?o0000oooo
ooooool0HOooool006?ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1>ooooo`03
o`000?oooooooooo067ooooo001Sooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0
C_ooool00ol0003oooooooooo`1Qooooo`00Hoooool00ol0003oooooooooo`13ooooo`Co000000?o
410@ooooooooool00oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo067ooooo001S
ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1>
ooooo`03o`000?oooooooooo067ooooo001Sooooo`03o`000?oooooooooo04Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo067ooooo001Sooooo`03
o`000?oooooooooo04Gooooo00?o0000ooooooooool01Oooool3o`0004kooooo00?o0000oooooooo
ool0HOooool006?ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo04kooooo00?o0000ooooooooool0HOooool006?ooooo00?o0000ooooooooool0AOoo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0HOoo
ool006?ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo04kooooo00?o0000ooooooooool0HOooool006?ooooo00?o0000ooooooooool0@oooool00omE
EEGoIVIVo`000007ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0HOooool006?o
oooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo067o
oooo001Sooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0C_ooool00ol0003ooooo
ooooo`1Qooooo`00Hoooool00ol0003oooooooooo`1=ooooo`;o0000Coooool00ol0003ooooooooo
o`1Qooooo`00Hoooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo04kooooo00?o0000
ooooooooool0HOooool006?ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1>oooo
o`03o`000?oooooooooo067ooooo001Sooooo`03o`000?oooooooooo04gooooo00?o0000oooooooo
ool0C_ooool00ol0003oooooooooo`1Qooooo`00Hoooool00ol0003oooooooooo`1=ooooo`03o`00
0?oooooooooo04kooooo00?o0000ooooooooool0HOooool006?ooooo00?o0000ooooooooool0COoo
ool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo067ooooo001Sooooo`03o`000?oooooo
oooo04gooooo0_l0001?ooooo`03o`000?oooooooooo067ooooo001Sooooo`03o`000?oooooooooo
04gooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1Qooooo`00Hoooool00ol0003o
ooooooooo`1=ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0HOooool006?ooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo067ooooo
001Sooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0C_ooool00ol0003ooooooooo
o`1Qooooo`00Hoooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo04kooooo00?o0000
ooooooooool0HOooool006?ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1>oooo
o`03o`000?oooooooooo067ooooo001Sooooo`03o`000?oooooooooo04gooooo0_l0001?ooooo`03
o`000?oooooooooo067ooooo001Sooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0
C_ooool00ol0003oooooooooo`1Qooooo`00Hoooool00ol0003oooooooooo`1=ooooo`03o`000?oo
oooooooo04kooooo00?o0000ooooooooool0HOooool006?ooooo00?o0000ooooooooool0COooool0
0ol0003oooooooooo`1>ooooo`03o`000?oooooooooo067ooooo001Sooooo`03o`000?oooooooooo
04gooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1Qooooo`00Hoooool00ol0003o
ooooooooo`1=ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0HOooool006?ooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo067ooooo
001Sooooo`03o`000?oooooooooo04gooooo0_l0001?ooooo`03o`000?oooooooooo067ooooo001S
ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1Q
ooooo`00Hoooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo04kooooo00?o0000oooo
ooooool0HOooool006?ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1>ooooo`03
o`000?oooooooooo067ooooo001Sooooo`03o`000?oooooooooo03?ooooo1?l000000ol@413ooooo
ooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool0C_ooool00ol0003oooooooooo`1Qooooo`00Hoooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
C_ooool00ol0003oooooooooo`1Qooooo`00Hoooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool00oooool3o`0004kooooo00?o0000ooooooooool0HOoo
ool006?ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1Qooooo`00Hoooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0HOooool006?ooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`1Qooooo`00Hoooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1>ooooo`03
o`000?oooooooooo067ooooo0008oooooeco0000=Oooool00omEEEGoIVIVo`00000=ooooo`Co0000
1_ooool00ol0003oooooooooo`1>oooooe_o00002Oooool00;?ooooo00?o0000ooooooooool0/_oo
ool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.15712, -1.64936, \
0.0219855, 0.0186261}}],

Cell[BoxData[
    FormBox[
      TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
        False,
        Editable->False], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[r, {x, 1, 2}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.928572 0.952381 0.0147151 0.0811478 [
[.21429 .00222 -9 -9 ]
[.21429 .00222 9 0 ]
[.40476 .00222 -9 -9 ]
[.40476 .00222 9 0 ]
[.59524 .00222 -9 -9 ]
[.59524 .00222 9 0 ]
[.78571 .00222 -9 -9 ]
[.78571 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .09586 -6 -4.5 ]
[.01131 .09586 0 4.5 ]
[.01131 .17701 -6 -4.5 ]
[.01131 .17701 0 4.5 ]
[.01131 .25816 -6 -4.5 ]
[.01131 .25816 0 4.5 ]
[.01131 .33931 -6 -4.5 ]
[.01131 .33931 0 4.5 ]
[.01131 .42045 -6 -4.5 ]
[.01131 .42045 0 4.5 ]
[.01131 .5016 -6 -4.5 ]
[.01131 .5016 0 4.5 ]
[.01131 .58275 -6 -4.5 ]
[.01131 .58275 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(1.2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(1.4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(1.6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(1.8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(2)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .09586 m
.03006 .09586 L
s
[(1)] .01131 .09586 1 0 Mshowa
.02381 .17701 m
.03006 .17701 L
s
[(2)] .01131 .17701 1 0 Mshowa
.02381 .25816 m
.03006 .25816 L
s
[(3)] .01131 .25816 1 0 Mshowa
.02381 .33931 m
.03006 .33931 L
s
[(4)] .01131 .33931 1 0 Mshowa
.02381 .42045 m
.03006 .42045 L
s
[(5)] .01131 .42045 1 0 Mshowa
.02381 .5016 m
.03006 .5016 L
s
[(6)] .01131 .5016 1 0 Mshowa
.02381 .58275 m
.03006 .58275 L
s
[(7)] .01131 .58275 1 0 Mshowa
.125 Mabswid
.02381 .03094 m
.02756 .03094 L
s
.02381 .04717 m
.02756 .04717 L
s
.02381 .0634 m
.02756 .0634 L
s
.02381 .07963 m
.02756 .07963 L
s
.02381 .11209 m
.02756 .11209 L
s
.02381 .12832 m
.02756 .12832 L
s
.02381 .14455 m
.02756 .14455 L
s
.02381 .16078 m
.02756 .16078 L
s
.02381 .19324 m
.02756 .19324 L
s
.02381 .20947 m
.02756 .20947 L
s
.02381 .2257 m
.02756 .2257 L
s
.02381 .24193 m
.02756 .24193 L
s
.02381 .27439 m
.02756 .27439 L
s
.02381 .29062 m
.02756 .29062 L
s
.02381 .30685 m
.02756 .30685 L
s
.02381 .32308 m
.02756 .32308 L
s
.02381 .35554 m
.02756 .35554 L
s
.02381 .37177 m
.02756 .37177 L
s
.02381 .38799 m
.02756 .38799 L
s
.02381 .40422 m
.02756 .40422 L
s
.02381 .43668 m
.02756 .43668 L
s
.02381 .45291 m
.02756 .45291 L
s
.02381 .46914 m
.02756 .46914 L
s
.02381 .48537 m
.02756 .48537 L
s
.02381 .51783 m
.02756 .51783 L
s
.02381 .53406 m
.02756 .53406 L
s
.02381 .55029 m
.02756 .55029 L
s
.02381 .56652 m
.02756 .56652 L
s
.02381 .59898 m
.02756 .59898 L
s
.02381 .61521 m
.02756 .61521 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .07963 m
.04262 .0801 L
.06244 .08076 L
.08255 .08164 L
.10458 .08287 L
.14509 .08596 L
.18408 .09017 L
.22553 .09639 L
.26546 .10462 L
.30387 .11538 L
.34474 .13107 L
.38409 .15206 L
.42192 .18012 L
.46221 .22231 L
.50098 .27992 L
.54221 .3649 L
.58192 .4678 L
.60195 .5207 L
.62011 .56233 L
.63024 .58057 L
.63488 .58736 L
.63978 .59332 L
.64228 .59585 L
.64503 .59822 L
.64755 .60001 L
.64986 .60131 L
.65116 .60191 L
.65258 .60244 L
.65335 .60267 L
.65407 .60286 L
.65481 .60302 L
.65549 .60314 L
.65671 .60327 L
.65735 .60331 L
.65804 .60332 L
.65873 .6033 L
.65946 .60325 L
.66075 .60307 L
.66199 .60281 L
.66333 .60242 L
.66576 .60142 L
.66812 .60011 L
.6703 .59861 L
.67525 .59416 L
.6805 .58794 L
.68924 .57441 L
.69886 .55561 L
.7392 .45206 L
.77803 .35138 L
.8193 .26702 L
Mistroke
.85906 .20849 L
.89731 .1682 L
.93801 .13735 L
.97619 .11615 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00BOooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`Go
0000;Oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B46ooooo`;o000000?o410@oooooooo
ool0:oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@
4?o<c<`0;Oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`0=?ooool5o`0000oooooo001;ooooo`03o`000?oooooooooo00Cooooo0_lQ8B44oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@0;oooool00ol0003oooooooooo`04ooooo`;o8B4Q1oooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oeEEEOmgMgOo
oooooiRHV?lQ8B40;oooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooo
oonHV9So8B4Q03Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00?ooooo`00Boooool00ol0003ooooo
ooooo`0;ooooo`03oiRHV?lQ8B7ok^k^033ooooo00?o0000ooooooooool02_ooool5o`0002oooooo
00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000002oooooo00?o0000oooooooo
ool02_ooool01Ol0003ooooooooooooooooo000003Gooooo00?oV9RHob4Q8Oo^k^h04?ooool004_o
oooo00?o0000ooooooooool03?ooool00onHV9So8B4Qonk^kP0_ooooo`03o`000?oooooooooo00[o
oooo00CoA4A4omgMgOoooooo0000<?ooool00ol0003oooooooooo`0:ooooo`05o`000?nHV9Sooooo
oiRHV?lQ8B40;oooool00ol0003oooooooooo`0:ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80=_oo
ool00onHV9So8B4Qonk^kP0?ooooo`00Boooool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKo
oooo02kooooo00?o0000ooooooooool02_ooool01?oMgMgoEEEEooooool0000`ooooo`03o`000?oo
oooooooo00[ooooo00Go0000oeEEEOl0003o410@olc<c00_ooooo`03o`000?oooooooooo00[ooooo
00Goc<c<o`000?l0003o0000olc<c00gooooo`03ogMgMomVIVKooooo00kooooo001;ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0;ooooo`03ogMg
Moo<c<co0000033ooooo00?o0000ooooooooool02_ooool00omEEEGoQhN7ooooo`0aooooo`03o`00
0?oooooooooo00[ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00go
oooo001;ooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@400_ooooo`03
o`000?oooooooooo00_ooooo00?ok^k^odA4A?l00000<?ooool00ol0003oooooooooo`0:ooooo`03
omgMgOl@413oV9RH037ooooo00?o0000ooooooooool02_ooool01Ol0003o^[Zjoooooonj^[[o0000
03Cooooo00Go0000okZj^_ooooooV9RHoa0@400?ooooo`00BOooool00omEEEGoIVIVo`00000<oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`0;Oooool00omEEEGoIVIVo`00000>ooooo`03ogMgMol0003o
oooo02gooooo00?oEEEEofIVI_l000003Oooool01?o<c<coA4A4o`000?l@410]ooooo`03oeEEEOmV
IVKo000000cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0dooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`03oooool00?ooooooJOooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool0
0ol0003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool001;o
oooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0003oooooooooo`3ooooooeCooooo
000:oooooooo0000Eol00008ooooo`004_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03_ooool001;ooooo00?o0000ooooooooool0?_ooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo00kooooo000Booooo`03o`000?oooooooooo0?oo
ooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool3o`000?ooooooE?oo
ool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0003oooooooooo`3ooooo
oeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0
oooooomDooooo`004_ooool00ol0003oooooooooo`3ooooooeCooooo000Booooo`?o0000oooooomD
ooooo`004_ooool00ol0003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?oo
ooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0003ooooooooo
o`3ooooooeCooooo000Booooo`?o0000oooooomDooooo`004_ooool00ol0003oooooooooo`3ooooo
oeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0
oooooomDooooo`004_ooool00ol0003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooo
oooo0?ooooooE?ooool001;ooooo6Ol0003oooooockooooo000Booooo`03o`000?oooooooooo01Ko
oooo2ol0003ooooooc?ooooo000Booooo`03o`000?oooooooooo027ooooo3_l0003oooooobGooooo
0008ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`0_ooooo`So0000oooo
oolMooooo`002_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Oooooo1Ol0003o
oooooaSooooo000:ooooo`03o`000?oooooooooo00Gooooo0ol0000looooo`Go0000oooooolCoooo
o`002_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo047ooooo1_l0003oooooo`go
oooo000:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Aoooool7o`000?oooooo
1_ooool000[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1>ooooo`Go0000oooo
ool1ooooo`002_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05?ooooo0ol0003m
ooooo`002?ooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo05Kooooo0ol0003joooo
o`004_ooool3o`0005Wooooo0ol0003gooooo`004_ooool00ol0003oooooooooo`1Looooo`?o0000
h_ooool2o`00013ooooo000Booooo`03o`000?oooooooooo05oooooo0ol0003Mooooo`;o00004_oo
ool001;ooooo00?o0000ooooooooool0H_ooool3o`000=Sooooo0_l0000Dooooo`004_ooool00ol0
003oooooooooo`1Uooooo`?o0000doooool2o`0001Kooooo000Booooo`?o0000J?ooool3o`000<oo
oooo00?o0000ooooooooool05_ooool001;ooooo00?o0000ooooooooool0Joooool2o`000<_ooooo
0_l0000Iooooo`004_ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo0<Kooooo0_l0
000Kooooo`004_ooool00ol0003oooooooooo`1^ooooo`;o0000a?ooool2o`0001gooooo000Boooo
o`03o`000?oooooooooo073ooooo0_l00031ooooo`03o`000?oooooooooo01gooooo000Booooo`03
o`000?oooooooooo07;ooooo00?o0000ooooooooool0_Oooool00ol0003oooooooooo`0Nooooo`00
4_ooool3o`0007?ooooo0_l0002looooo`03o`000?oooooooooo01oooooo000Booooo`03o`000?oo
oooooooo07Gooooo0_l0002hooooo`;o00008_ooool001;ooooo00?o0000ooooooooool0Moooool0
0ol0003oooooooooo`2dooooo`03o`000?oooooooooo02;ooooo000Booooo`03o`000?oooooooooo
07Sooooo0_l0002cooooo`03o`000?oooooooooo02?ooooo000Booooo`03o`000?oooooooooo07[o
oooo00?o0000ooooooooool0[_ooool2o`0002Kooooo000Booooo`?o0000Noooool2o`000:gooooo
00?o0000ooooooooool09_ooool001;ooooo00?o0000ooooooooool0OOooool00ol0003ooooooooo
o`2Yooooo`03o`000?oooooooooo02Oooooo000Booooo`03o`000?oooooooooo07kooooo0_l0002X
ooooo`03o`000?oooooooooo02Sooooo000Booooo`03o`000?oooooooooo083ooooo00?o0000oooo
ooooool0Y?ooool00ol0003oooooooooo`0Yooooo`001oooool5o`0000Kooooo00?o0000oooooooo
ool0POooool00ol0003oooooooooo`2Sooooo`03o`000?oooooooooo02Wooooo0007ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`22ooooo`;o0000X_ooool00ol0003o
ooooooooo`0Zooooo`002?ooool00onHV9So8B4Qonk^kP07ooooo`?o0000Q?ooool00ol0003ooooo
ooooo`2Nooooo`03o`000?oooooooooo02_ooooo0009ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o
0000ooooooooool0QOooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo02cooooo000:
ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`2J
ooooo`03o`000?oooooooooo02gooooo000;ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0Qoooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo02kooooo0007ooooo`05
o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo
09Kooooo00?o0000ooooooooool0;oooool000Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006oooo
o`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`0`oooo
o`004_ooool3o`0008[ooooo00?o0000ooooooooool0T_ooool00ol0003oooooooooo`0aooooo`00
4_ooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool0
<_ooool001;ooooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`2>ooooo`03o`000?oo
oooooooo03?ooooo000Booooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool0S?ooool0
0ol0003oooooooooo`0dooooo`004_ooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo
08[ooooo00?o0000ooooooooool0=Oooool001;ooooo0ol0002?ooooo`03o`000?oooooooooo08So
oooo00?o0000ooooooooool0=_ooool001;ooooo00?o0000ooooooooool0T?ooool00ol0003ooooo
ooooo`27ooooo`03o`000?oooooooooo03Kooooo000Booooo`03o`000?oooooooooo097ooooo00?o
0000ooooooooool0QOooool00ol0003oooooooooo`0gooooo`004_ooool00ol0003oooooooooo`2B
ooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool0>?ooool001;ooooo00?o0000oooo
ooooool0Toooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo03Sooooo000Booooo`03
o`000?oooooooooo09?ooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`0iooooo`00
4_ooool3o`0009Cooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`0jooooo`004_oo
ool00ol0003oooooooooo`2Eooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool0>_oo
ool001;ooooo00?o0000ooooooooool0UOooool00ol0003oooooooooo`1mooooo`03o`000?oooooo
oooo03_ooooo000Booooo`03o`000?oooooooooo09Kooooo00?o0000ooooooooool0Noooool00ol0
003oooooooooo`0looooo`004_ooool00ol0003oooooooooo`2Gooooo`03o`000?oooooooooo07[o
oooo00?o0000ooooooooool0??ooool001;ooooo0ol0002Gooooo`03o`000?oooooooooo07Wooooo
00?o0000ooooooooool0?Oooool001;ooooo00?o0000ooooooooool0V?ooool00ol0003ooooooooo
o`1hooooo`03o`000?oooooooooo03gooooo000Booooo`03o`000?oooooooooo09Wooooo00?o0000
ooooooooool0M_ooool00ol0003oooooooooo`0nooooo`001oooool01OnHV9So410@o`000?lb<S;o
c<c<00Kooooo00?o0000ooooooooool0VOooool00ol0003oooooooooo`1eooooo`03o`000?oooooo
oooo03oooooo0007ooooo`05oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0003oooooooooo`2J
ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0?oooool000_ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo07?ooooo00?o0000oooo
ooooool0@?ooool000[ooooo00?oZJVYoa0@4?ooool01Oooool3o`0009_ooooo00?o0000oooooooo
ool0LOooool00ol0003oooooooooo`11ooooo`002Oooool00ol@413o0000okZj^P06ooooo`03o`00
0?oooooooooo09cooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`11ooooo`002_oo
ool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo09cooooo00?o0000ooooooooool0Kooo
ool00ol0003oooooooooo`12ooooo`001oooool01Ol@413oV9RHoooooonj^[[o000000Kooooo00?o
0000ooooooooool0WOooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo04?ooooo0007
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`2Nooooo`03o`000?oo
oooooooo06cooooo00?o0000ooooooooool0@oooool001;ooooo0ol0002Nooooo`03o`000?oooooo
oooo06_ooooo00?o0000ooooooooool0A?ooool001;ooooo00?o0000ooooooooool0Woooool00ol0
003oooooooooo`1Zooooo`03o`000?oooooooooo04Cooooo000Booooo`03o`000?oooooooooo0:3o
oooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`15ooooo`004_ooool00ol0003ooooo
ooooo`2Pooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0AOooool001;ooooo00?o
0000ooooooooool0XOooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo04Kooooo000B
ooooo`03o`000?oooooooooo0:7ooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`16
ooooo`004_ooool3o`000:;ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`17oooo
o`004_ooool00ol0003oooooooooo`2Rooooo`03o`000?oooooooooo06Cooooo00?o0000oooooooo
ool0Aoooool001;ooooo00?o0000ooooooooool0Xoooool00ol0003oooooooooo`1Rooooo`03o`00
0?oooooooooo04Sooooo000Booooo`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool0H_oo
ool00ol0003oooooooooo`18ooooo`004_ooool00ol0003oooooooooo`2Tooooo`03o`000?oooooo
oooo063ooooo00?o0000ooooooooool0BOooool001;ooooo0ol0002Tooooo`03o`000?oooooooooo
063ooooo00?o0000ooooooooool0BOooool001;ooooo00?o0000ooooooooool0YOooool00ol0003o
ooooooooo`1Nooooo`03o`000?oooooooooo04[ooooo000Booooo`03o`000?oooooooooo0:Gooooo
00?o0000ooooooooool0G_ooool00ol0003oooooooooo`1:ooooo`004_ooool00ol0003ooooooooo
o`2Vooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0B_ooool001;ooooo00?o0000
ooooooooool0Y_ooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo04_ooooo000Boooo
o`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`1;oooo
o`004_ooool3o`000:Oooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`1<ooooo`00
4_ooool00ol0003oooooooooo`2Wooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0
C?ooool001;ooooo00?o0000ooooooooool0Z?ooool00ol0003oooooooooo`1Hooooo`03o`000?oo
oooooooo04gooooo0009ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`2X
ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0COooool000[ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`2Yooooo`03o`000?oooooooooo05Kooooo00?o0000oooo
ooooool0C_ooool000Oooooo1Ol00006ooooo`?o0000ZOooool00ol0003oooooooooo`1Fooooo`03
o`000?oooooooooo04kooooo0007ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000oooooooo
ool0Z_ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo04oooooo0007ooooo`04omgM
gOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0Z_ooool00ol0003oooooooooo`1Dooooo`03
o`000?oooooooooo04oooooo0008ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0
Zoooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo053ooooo0008ooooo`03onk^k_m4
A4Co000000Oooooo00?o0000ooooooooool0Zoooool00ol0003oooooooooo`1Booooo`03o`000?oo
oooooooo053ooooo0009ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0[?ooool0
0ol0003oooooooooo`1@ooooo`03o`000?oooooooooo057ooooo000Booooo`?o0000[?ooool00ol0
003oooooooooo`1@ooooo`03o`000?oooooooooo057ooooo000Booooo`03o`000?oooooooooo0:go
oooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1Booooo`004_ooool00ol0003ooooo
ooooo`2]ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0D_ooool001;ooooo00?o
0000ooooooooool0[_ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo05;ooooo000B
ooooo`03o`000?oooooooooo0:kooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1C
ooooo`004_ooool3o`000:oooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`1Coooo
o`004_ooool00ol0003oooooooooo`2_ooooo`03o`000?oooooooooo04[ooooo00?o0000oooooooo
ool0E?ooool001;ooooo00?o0000ooooooooool0[oooool00ol0003oooooooooo`1:ooooo`03o`00
0?oooooooooo05Cooooo000Booooo`03o`000?oooooooooo0;3ooooo00?o0000ooooooooool0B?oo
ool00ol0003oooooooooo`1Eooooo`004_ooool00ol0003oooooooooo`2`ooooo`03o`000?oooooo
oooo04Sooooo00?o0000ooooooooool0EOooool001;ooooo00?o0000ooooooooool0/Oooool00ol0
003oooooooooo`17ooooo`03o`000?oooooooooo05Gooooo000Booooo`?o0000/Oooool00ol0003o
ooooooooo`16ooooo`03o`000?oooooooooo05Kooooo000Booooo`03o`000?oooooooooo0;7ooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1Fooooo`004_ooool00ol0003ooooooooo
o`2booooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0Eoooool001;ooooo00?o0000
ooooooooool0/_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo05Oooooo000Boooo
o`03o`000?oooooooooo0;?ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`1Goooo
o`004_ooool00ol0003oooooooooo`2cooooo`03o`000?oooooooooo04;ooooo00?o0000oooooooo
ool0F?ooool001;ooooo0ol0002cooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0
F?ooool001;ooooo00?o0000ooooooooool0]?ooool00ol0003oooooooooo`10ooooo`03o`000?oo
oooooooo05Wooooo000Booooo`03o`000?oooooooooo0;Cooooo00?o0000ooooooooool0@?ooool0
0ol0003oooooooooo`1Iooooo`002?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool0]Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo05Wooooo000;oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0]Oooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo05[ooooo000<ooooo`03o`000?oooooooooo00?ooooo0ol0002eooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool0F_ooool000_ooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2fooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0
Foooool000Sooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;Kooooo
00?o0000ooooooooool0??ooool00ol0003oooooooooo`1Kooooo`002?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0;Oooooo00?o0000ooooooooool0>_ooool00ol0003ooooooooo
o`1Looooo`002?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Oooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`1Looooo`002?ooool4o`0000Kooooo00?o0000oooo
ooooool0]oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo05cooooo000Booooo`?o
0000^?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05gooooo000Booooo`03o`00
0?oooooooooo0;Sooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Mooooo`004_oo
ool00ol0003oooooooooo`2iooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0G_oo
ool001;ooooo00?o0000ooooooooool0^Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo05kooooo000Booooo`03o`000?oooooooooo0;Wooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`1Nooooo`004_ooool3o`000;[ooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`1Oooooo`004_ooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool0Goooool001;ooooo00?o0000ooooooooool0^oooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo063ooooo000Booooo`03o`000?oooooooooo0;_ooooo00?o0000
ooooooooool0<_ooool00ol0003oooooooooo`1Pooooo`004_ooool00ol0003oooooooooo`2koooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0H?ooool001;ooooo00?o0000oooooooo
ool0_?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo067ooooo000Booooo`?o0000
_?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo067ooooo000Booooo`03o`000?oo
oooooooo0;gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Qooooo`004_ooool0
0ol0003oooooooooo`2mooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0H_ooool0
01;ooooo00?o0000ooooooooool0_Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
06;ooooo000Booooo`03o`000?oooooooooo0;kooooo00?o0000ooooooooool0;?ooool00ol0003o
ooooooooo`1Sooooo`004_ooool3o`000;kooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`1Sooooo`004_ooool00ol0003oooooooooo`2oooooo`03o`000?oooooooooo02_ooooo00?o
0000ooooooooool0Hoooool001;ooooo00?o0000ooooooooool0_oooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo06Cooooo0007ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool0
0ol0003oooooooooo`2oooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0I?ooool0
00Oooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0<3ooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`1Tooooo`001oooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool0`?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo06Gooooo0007ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`000<3ooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`1Uooooo`001oooool01Ol0003oEEEEo`000?l@413o
c<c<00Kooooo00?o0000ooooooooool0`Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo06Kooooo0007ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0`Oooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo06Kooooo0007ooooo`03omgMgOl@413oV9RH00So
oooo00?o0000ooooooooool0`_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06Ko
oooo0008ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0`_ooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo06Oooooo000Booooo`?o0000`_ooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo06Oooooo000Booooo`03o`000?oooooooooo0<?ooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`1Wooooo`004_ooool00ol0003oooooooooo`33
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0J?ooool001;ooooo00?o0000oooo
ooooool0a?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo06Sooooo000Booooo`03
o`000?oooooooooo0<Cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1Xooooo`00
4_ooool00ol0003oooooooooo`35ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
JOooool001;ooooo0ol00035ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0JOoo
ool001;ooooo00?o0000ooooooooool0aOooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo06[ooooo000Booooo`03o`000?oooooooooo0<Kooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`1Zooooo`004_ooool00ol0003oooooooooo`36ooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool0J_ooool001;ooooo00?o0000ooooooooool0aoooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo06_ooooo000Booooo`?o0000aoooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo06_ooooo000Booooo`03o`000?oooooooooo0<Sooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`1[ooooo`004_ooool00ol0003oooooooooo`38oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0K?ooool001;ooooo00?o0000oooooooo
ool0b?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo06cooooo000Booooo`03o`00
0?oooooooooo0<Wooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1]ooooo`004_oo
ool00ol0003oooooooooo`39ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0KOoo
ool001;ooooo0ol0003:ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0K_ooool0
01;ooooo00?o0000ooooooooool0b_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
06oooooo000Booooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`1_ooooo`002Oooool00ol0003ok^k^ooooo`06ooooo`03o`000?oooooooooo0<_ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`1`ooooo`002Oooool00omEEEGoZJVYoooo
o`06ooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`1`ooooo`002Oooool00onYZJWoEEEEooooo`06ooooo`?o0000c?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo077ooooo000:ooooo`03ob4Q8Ooooooooooo00Gooooo00?o0000oooo
ooooool0cOooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo07;ooooo000:ooooo`03
oeEEEOo<c<cooooo00Gooooo00?o0000ooooooooool0c_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo07?ooooo000:ooooo`03ojVYZOmgMgOooooo00Gooooo00?o0000ooooooooool0
coooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo07?ooooo0007ooooo`05oa0@4?oo
oooooooooooooolb<S801_ooool00ol0003oooooooooo`3@ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0M?ooool000Oooooo1Ol00006ooooo`03o`000?oooooooooo0=3ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`1eooooo`004_ooool3o`000=7ooooo0_l00006
ooooo`;o0000N?ooool001;ooooo00?o0000ooooooooool0doooool6o`0007[ooooo000Booooo`03
o`000?oooooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_oo
ool00ol0003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0
01;ooooo0ol0003ooooooeCooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0.942032, -0.56032, \
0.00384656, 0.0451447}}],

Cell[BoxData[
    FormBox[
      TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
        False,
        Editable->False], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(bestimmt = \((RT /. x \[Rule] 2)\) - \((RT /. x \[Rule] 1)\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(-\(1\/2\)\)\ \[ImaginaryI]\ \(log(\(-2\) - \
\[ImaginaryI])\) + 1\/2\ \[ImaginaryI]\ \(log(\(-2\) + \[ImaginaryI])\) - 
      1\/2\ \[ImaginaryI]\ \(log(2 - 2\ \[ImaginaryI])\) + 
      1\/2\ \[ImaginaryI]\ \(log(2 + 2\ \[ImaginaryI])\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(N[bestimmt]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(-3.4633432079864352`\) + 
      0.`\ \[ImaginaryI]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(bestimmt = \((int /. x \[Rule] 2)\) - \((int /. 
            x \[Rule] 1)\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\[Pi]\/4 - \(tan\^\(-1\)\)(2)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(N[bestimmt]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(-0.32175055439664213`\)\)], "Output"]
}, Open  ]],

Cell["komplizierter in Mathematica 5.0", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(bestimmt = \[Integral]\_1\%2 r \[DifferentialD]x\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(5\ \[Pi]\)\/4 - \(tan\^\(-1\)\)(2)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(N[bestimmt]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`2.819842099193151`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(int = \[Integral]r \[DifferentialD]x\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`1\/2\ \(\(tan\^\(-1\)\)(\(x\ \((x\^2 - 3)\)\)\/\(x\^2 \
- 2\))\) - 
      1\/2\ \(\(tan\^\(-1\)\)(\(x\ \((x\^2 - 3)\)\)\/\(2 - x\^2\))\)\)], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[int, {x, \(-3\), 3}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.308853 0.187902 [
[.02381 .29635 -6 -9 ]
[.02381 .29635 6 0 ]
[.18254 .29635 -6 -9 ]
[.18254 .29635 6 0 ]
[.34127 .29635 -6 -9 ]
[.34127 .29635 6 0 ]
[.65873 .29635 -3 -9 ]
[.65873 .29635 3 0 ]
[.81746 .29635 -3 -9 ]
[.81746 .29635 3 0 ]
[.97619 .29635 -3 -9 ]
[.97619 .29635 3 0 ]
[.4875 .027 -24 -4.5 ]
[.4875 .027 0 4.5 ]
[.4875 .12095 -12 -4.5 ]
[.4875 .12095 0 4.5 ]
[.4875 .2149 -24 -4.5 ]
[.4875 .2149 0 4.5 ]
[.4875 .4028 -18 -4.5 ]
[.4875 .4028 0 4.5 ]
[.4875 .49676 -6 -4.5 ]
[.4875 .49676 0 4.5 ]
[.4875 .59071 -18 -4.5 ]
[.4875 .59071 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30885 m
.02381 .3151 L
s
[(-3)] .02381 .29635 0 1 Mshowa
.18254 .30885 m
.18254 .3151 L
s
[(-2)] .18254 .29635 0 1 Mshowa
.34127 .30885 m
.34127 .3151 L
s
[(-1)] .34127 .29635 0 1 Mshowa
.65873 .30885 m
.65873 .3151 L
s
[(1)] .65873 .29635 0 1 Mshowa
.81746 .30885 m
.81746 .3151 L
s
[(2)] .81746 .29635 0 1 Mshowa
.97619 .30885 m
.97619 .3151 L
s
[(3)] .97619 .29635 0 1 Mshowa
.125 Mabswid
.05556 .30885 m
.05556 .3126 L
s
.0873 .30885 m
.0873 .3126 L
s
.11905 .30885 m
.11905 .3126 L
s
.15079 .30885 m
.15079 .3126 L
s
.21429 .30885 m
.21429 .3126 L
s
.24603 .30885 m
.24603 .3126 L
s
.27778 .30885 m
.27778 .3126 L
s
.30952 .30885 m
.30952 .3126 L
s
.37302 .30885 m
.37302 .3126 L
s
.40476 .30885 m
.40476 .3126 L
s
.43651 .30885 m
.43651 .3126 L
s
.46825 .30885 m
.46825 .3126 L
s
.53175 .30885 m
.53175 .3126 L
s
.56349 .30885 m
.56349 .3126 L
s
.59524 .30885 m
.59524 .3126 L
s
.62698 .30885 m
.62698 .3126 L
s
.69048 .30885 m
.69048 .3126 L
s
.72222 .30885 m
.72222 .3126 L
s
.75397 .30885 m
.75397 .3126 L
s
.78571 .30885 m
.78571 .3126 L
s
.84921 .30885 m
.84921 .3126 L
s
.88095 .30885 m
.88095 .3126 L
s
.9127 .30885 m
.9127 .3126 L
s
.94444 .30885 m
.94444 .3126 L
s
.25 Mabswid
0 .30885 m
1 .30885 L
s
.5 .027 m
.50625 .027 L
s
[(-1.5)] .4875 .027 1 0 Mshowa
.5 .12095 m
.50625 .12095 L
s
[(-1)] .4875 .12095 1 0 Mshowa
.5 .2149 m
.50625 .2149 L
s
[(-0.5)] .4875 .2149 1 0 Mshowa
.5 .4028 m
.50625 .4028 L
s
[(0.5)] .4875 .4028 1 0 Mshowa
.5 .49676 m
.50625 .49676 L
s
[(1)] .4875 .49676 1 0 Mshowa
.5 .59071 m
.50625 .59071 L
s
[(1.5)] .4875 .59071 1 0 Mshowa
.125 Mabswid
.5 .04579 m
.50375 .04579 L
s
.5 .06458 m
.50375 .06458 L
s
.5 .08337 m
.50375 .08337 L
s
.5 .10216 m
.50375 .10216 L
s
.5 .13974 m
.50375 .13974 L
s
.5 .15853 m
.50375 .15853 L
s
.5 .17732 m
.50375 .17732 L
s
.5 .19611 m
.50375 .19611 L
s
.5 .23369 m
.50375 .23369 L
s
.5 .25248 m
.50375 .25248 L
s
.5 .27127 m
.50375 .27127 L
s
.5 .29006 m
.50375 .29006 L
s
.5 .32764 m
.50375 .32764 L
s
.5 .34643 m
.50375 .34643 L
s
.5 .36522 m
.50375 .36522 L
s
.5 .38401 m
.50375 .38401 L
s
.5 .42159 m
.50375 .42159 L
s
.5 .44038 m
.50375 .44038 L
s
.5 .45917 m
.50375 .45917 L
s
.5 .47796 m
.50375 .47796 L
s
.5 .51555 m
.50375 .51555 L
s
.5 .53434 m
.50375 .53434 L
s
.5 .55313 m
.50375 .55313 L
s
.5 .57192 m
.50375 .57192 L
s
.5 .00821 m
.50375 .00821 L
s
.5 .6095 m
.50375 .6095 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .08339 m
.06244 .09184 L
.08255 .09738 L
.10458 .10478 L
.12507 .1135 L
.14415 .12413 L
.15465 .13154 L
.16457 .14003 L
.17341 .14931 L
.18314 .16218 L
.19284 .17913 L
.19779 .1901 L
.20312 .2043 L
.20809 .22048 L
.21264 .23846 L
.22156 .28537 L
.24215 .44844 L
.24731 .48669 L
.25218 .51713 L
.25691 .54167 L
.26127 .56044 L
.27015 .59011 L
.27256 .59666 L
.27374 .59968 L
.27482 .60233 L
.27595 .01472 L
.27717 .01751 L
.27975 .0231 L
.29946 .05576 L
.31855 .07832 L
.33931 .09895 L
.38009 .13803 L
.41935 .1821 L
.4571 .23566 L
.49731 .30407 L
.536 .37097 L
.57714 .43114 L
.61676 .47647 L
.65487 .51324 L
.67612 .53385 L
.69543 .55534 L
.70507 .56828 L
.71014 .57607 L
.71551 .58534 L
.72021 .59453 L
.7215 .59726 L
.72288 .60032 L
.72419 .60332 L
.72538 .01586 L
.72654 .01873 L
Mistroke
.72761 .0215 L
.73004 .02814 L
.73447 .0418 L
.73957 .06061 L
.74507 .08573 L
.75504 .14771 L
.77366 .29963 L
.78319 .35943 L
.78859 .38446 L
.79363 .4032 L
.80381 .43137 L
.80952 .44318 L
.81471 .4522 L
.82399 .46528 L
.83383 .47613 L
.84463 .48561 L
.85461 .49277 L
.87412 .50381 L
.89241 .51178 L
.93115 .5242 L
.97234 .53358 L
.97619 .53432 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003o/oooool0
0ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo001S
ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0/_ooool006?ooooo00?o0000oooo
ooooool0COooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo067ooooo001Sooooo`03
o`000?oooooooooo03?ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1Qoooo
o`00Hoooool2o`0003Kooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`1>ooooo`;o0000H_ooool006?ooooo0_l0000[ooooo`Ko0000
1Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
C_ooool2o`0006;ooooo001Sooooo`03o`000?oooooo000003Gooooo00?o0000ooooooooool03_oo
ool00omgMgOo<S8booooo`04ooooo`?o0000C_ooool2o`0006;ooooo001Sooooo`03o`000?oooooo
000003Gooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool0C_ooool2o`0006;ooooo001Sooooo`04o`000?ooooooooooo`0003Cooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04kooooo00?o
0000ooooool00000HOooool006?ooooo00Go0000ooooooooooooooooo`00000cooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1>ooooo`03o`000?oo
oooo0000067ooooo001Sooooo`05o`000?ooooooooooooooool00000<Oooool00omEEEGoIVIVo`00
000=ooooo`Co00001_ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooo0000067ooooo001S
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`1>
ooooo`04o`000?ooooooooooo`00063ooooo001Sooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0B?ooool00ol0003oooooooooo`1>ooooo`04o`000?ooooooooooo`00063ooooo001S
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Aoooool2o`0004oooooo00Co0000
oooooooooooo0000H?ooool006?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`16
ooooo`03o`000?oooooooooo04kooooo00Go0000ooooooooooooooooo`00001Oooooo`00Hoooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0C_ooool0
1Ol0003ooooooooooooooooo000005oooooo001Sooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0AOooool00ol0003oooooooooo`1>ooooo`05o`000?ooooooooooooooool00000Gooo
ool006?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooo
oooo04kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Looooo`00Hoooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0C_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo05cooooo001Sooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0@oooool2o`0004oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`1Looooo`00Hoooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04;ooooo
00?o0000ooooooooool0C_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05cooooo
001Sooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0@Oooool00ol0003ooooooooo
o`1>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Foooool006?ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo04kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1Kooooo`00Hoooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo05_ooooo001Sooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0Foooool006?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0nooooo`03o`00
0?oooooooooo04kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Kooooo`002?oo
ool3o`0005Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0mooooo`;o0000Cooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05[ooooo000;ooooo`Go0000Doooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0C_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo05[ooooo000@ooooo`Go0000C_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0C_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo05[ooooo000Eooooo`Co0000B_ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0C_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo05[ooooo000Iooooo`?o0000Aoooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0C_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo05[ooooo000Looooo`?o0000A?ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0C_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo05[ooooo000Oooooo`?o0000@Oooool00ol0003oooooooooo`0C
ooooo`;o0000>?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0FOooool002;ooooo0ol0000nooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0=Oooool2o`0004oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Ioooo
o`009Oooool2o`0003cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo04kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Iooooo`00
9oooool3o`0003Wooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo04kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Iooooo`00:_oo
ool3o`0003Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo04kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Iooooo`00;Oooool2
o`0003Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Wooooo`Co000000?o410@
ooooooooool00oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0FOooool002oooooo0_l0000booooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`1Iooooo`00<Oooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool6o`0000Gooooo00?o0000oooooooo
ool01Oooool3o`0004kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Hooooo`00
<_ooool2o`0002oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo05Sooooo000dooooo`;o0000;Oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1>ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0F?ooool003Kooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0F?ooool0
03Oooooo0_l0000Zooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`1Hooooo`00>Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool08?ooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo04ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Hooooo`00>_ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`1>ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0F?ooool003_ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02Sooooo0_l0
001?ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Eoooool003_ooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool0C_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Oooooo000loooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo04kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Goooo
o`00?Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0Eoooool003kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo05Oooooo000oooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`1Gooooo`00@?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0Eoooool0047ooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo02;ooooo0_l0001?ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0Eoooool004;ooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0C_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo05Kooooo0012ooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo04kooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Fooooo`00@oooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`1>ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0E_ooool004?ooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool0C_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05Kooooo0014oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo04kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Foooo
o`00A?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0E_ooool004Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo01_ooooo0_l0001?ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
E_ooool004Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo05Kooooo0016ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`1Eooooo`00A_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0EOooool004Oooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0booooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0C_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo05Gooooo0017ooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04kooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Eooooo`00B?ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool05oooool2o`0004oooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`1Eooooo`00B?ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1>
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0EOooool004Sooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05Gooooo0019ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo04kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Dooooo`00
BOooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
E?ooool004Wooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0booooo`06onk^k_lb
<S;o0000oc8b<_o^k^ko00001?ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo04kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Doooo
o`00BOooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03;ooooo00KoMgMgoiRHV?oo
ooooV9RHogMgMol00004ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo04kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Dooooo`00B_ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo02[ooooo1_l00002ooooo`07oa0@4?oooooooooo
ooooool@413oooooo`00000>ooooo`03o`000?oooooooooo00?ooooo0ol0001>ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0E?ooool004[ooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0booooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooooooo
o`0:ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0C_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo05Cooooo001:ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0<_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool01ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0C_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo05Cooooo001:ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool0<_ooool01Ol@413ooooooooooooooooo410@00?ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`1Dooooo`00B_ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo03;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0Doooool004_ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`0booooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`04ooooo`Co0000
1_ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
Doooool004_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0looooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo05?ooooo001;ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0?Oooool0
0ol0003oooooooooo`0=ooooo`;o0000Coooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo05?ooooo001<ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0?_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`1Cooooo`00C?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0Doooool004cooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0oooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0C_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo05?ooooo001<ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04kooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`1Cooooo`00C?ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1>
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0D_ooool004gooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05;ooooo001=ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`09ooooo`;o
0000Coooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05;ooooo001=ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo04kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Booooo`00COoo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0D_oo
ool004gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`13ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo05;ooooo001>ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0A?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`1Booooo`00C_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04Co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0DOooool000Wooooo00GoV9RHoa0@4?l0003o<S8bolc<c00dooooo`Go
00001oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Kooooo1?l000000ol@413o
ooooooooo`0Xooooo`03o`000?oooooooooo00Gooooo0_l0000eooooo`Co000000?o410@oooooooo
ool04oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo1Ol0000dooooo`05
oiRHV?l@413o0000oc8b<_o<c<`02?ooool000Wooooo00Go410@okZj^_ooooooMgMgoc8b<P0doooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00dooooo`05oa0@4?nj^[[oooooogMgMolb<S80
2?ooool00003ooooool0003o000000Co00001_ooool00ol0003oooooooooo`0Zooooo`Ko00000ooo
ool00onHV9So8B4Qonk^kP08ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03Ooo
ool6o`0000Gooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00cooooo00?oV9RHob4Q8Oo^k^h0>Oooool00ol0003oooooooooo`06ooooo`003?ooool0
0onYZJWo410@ooooo`0eooooo`03oiRHV?lQ8B7ok^k^00Sooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0=ooooo`03oiRHV?lQ8B7ok^k^03Oooooo00?oZJVYoa0@4?ooool01oooool0
00_ooooo00?o410@o`000?nj^[X0=oooool00omgMgOoIVIVooooo`07ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03_ooool00omgMgOoIVIVooooo`0eooooo`03oa0@4?l0003o^[Zj
00Sooooo000<ooooo`03okZj^_lQ8B7ooooo03Oooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0=Oooool00onj^[[o
8B4Qooooo`07ooooo`002Oooool01Ol@413oV9RHoooooonj^[[o000003Cooooo00Go0000okZj^_oo
ooooV9RHoa0@4008ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool01Ol0
003o^[ZjoooooonHV9So410@03Cooooo00Go410@oiRHV?oooooo^[Zjo`000008ooooo`002Oooool0
1OnYZJWo410@o`000?l@413oZJVY03Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c008ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool05_ooool00omEEEGoIVIVo`00000`ooooo`04o`00
0?ooooooooooooooo`;o0000=Oooool00omEEEGoIVIVo`00000Gooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool02_ooool01OnHV9So410@o`000?lQ8B7oc<c<03Cooooo00GoZJVYoa0@
4?l0003o410@ojVYZ@08ooooo`00Coooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
04Wooooo00Go0000ooooooooooooooooo`00001@ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool0D?ooool004oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1:oooo
o`04o`000?ooooooooooo`00053ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1@
ooooo`00D?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04_ooooo00?o0000oooo
ool00000D?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo053ooooo001@ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool0Boooool00ol0003oooooo`00001@ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool0D?ooool0053ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`1<ooooo`;o0000D?ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo053ooooo001@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0C?oo
ool2o`00053ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1@ooooo`00ool0001X
o`00007ooooo0008ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`09ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01oooool2
o`0000_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Gooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0fooooo`;o0000=oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo00Oooooo001Aooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0C_ooool00ol0
003oooooo`00001=ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Coooool0057o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooo000004go
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1?ooooo`00DOooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo04kooooo00Co0000oooooooooooo0000C?ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo04oooooo001Aooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0C_ooool2o`000003ooooool0003ooooo04_ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`1?ooooo`00DOooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo04kooooo00Go0000ooooooooooooooooo`00001;ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0Coooool0057ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`1>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0B?ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo04kooooo001Aooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool0C_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04Sooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`1>ooooo`00D_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo04kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`17oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C_ooool005;ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0Aoooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04kooooo001Booooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo04Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1>ooooo`00D_oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04kooooo0_l00005ooooo`03o`000?oo
oooooooo04Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1>ooooo`00D_ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`15ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C_ooool0
05;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
04gooooo001Booooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0C_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`1=ooooo`00D_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0COooool005?ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`1>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo04gooooo001Cooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0C_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04;ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`1=ooooo`00Doooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo04kooooo0_l0000:ooooo`03o`000?oooooooooo047ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`1=ooooo`00Doooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo04kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`11ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool0C?ooool005?ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
@?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04cooooo001Cooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1<ooooo`00Doooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0C?ooool0
05Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
04cooooo001Dooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0C_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`1;ooooo`00E?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04kooooo
0_l0000>ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`1;ooooo`00E?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04kooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0Boooool005Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1>
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo04_ooooo001Dooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`1:ooooo`00E?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_ooool005Cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0cooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1:ooooo`00EOooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo03?ooooo00Go410@oooooooooooooooooa0@400@
ooooo`03o`000?oooooooooo00?ooooo0ol0000Aooooo`03o`000?oooooooooo03Wooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`19ooooo`00EOooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo03?ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool0BOooool005Gooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0cooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0gooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0BOooool005Gooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0cooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0=oooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo04Sooooo001Eooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0<oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`18ooooo`00EOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`18ooooo`00EOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04kooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool0Aoooool005Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1>oooo
o`;o00005oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool0Aoooool005Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1>ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo04Kooooo001Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
C_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`16ooooo`00E_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo04kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0A_ooool005Kooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`1>ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04Gooooo001Fooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`15ooooo`00E_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0A?ooool005Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`1>ooooo`;o00007?ooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0A?ooool005Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04?ooooo001G
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`13
ooooo`00Eoooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04kooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool0@_ooool005Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1>ooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo047ooooo001Gooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
C_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`11ooooo`00Eoooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo04kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool0@?ooool005Oooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`1>ooooo`;o00008_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool0?oooool005Oooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`1>ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo03oooooo001Gooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0nooooo`00F?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0?Oooool005Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03cooooo001H
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0k
ooooo`00F?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04kooooo0_l0000Xoooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0joooo
o`00F?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04kooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool0>Oooool005Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1>ooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo03Sooooo001Hooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0C_oo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0:?oo
ool2o`0003Sooooo001Hooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0C_ooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`0eooooo`00F?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
04Cooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03Cooooo001Hooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0/ooooo`;o
0000=?ooool005Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`16ooooo`03o`00
0?oooooooooo00Gooooo0ol0000^ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
;_ooool2o`0003;ooooo001Iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0A_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02oooooo001Iooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0aooooo`;o0000;oooool0
05Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
03?ooooo0ol0000/ooooo`00FOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool0=_ooool3o`0002Wooooo001Jooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0A?ooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0iooooo`?o00009_ooool005[ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo03Cooooo0_l0
000Gooooo`03o`000?oooooooooo03cooooo0ol0000Sooooo`00F_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo04kooooo0_l0000gooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0?oooool3o`00023ooooo001Jooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0@_ooool2o`0001kooooo001Jooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0C_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool0A?ooool3o`0001_ooooo001Kooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
C_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
Aoooool4o`0001Oooooo001Kooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0C_oo
ool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Booo
ool5o`0001;ooooo001Kooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0C_ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0D?ooool5
o`0000gooooo001Kooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0C_ooool00ol0
003oooooooooo`0looooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0EOooool3o`00
00[ooooo001Kooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0C_ooool2o`0003go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo00Oo
oooo001Looooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0C_ooool00ol0003ooooo
ooooo`0mooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0H_ooool005cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo03kooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`1Rooooo`00G?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo06;ooooo001Looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0H_ooool005cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1>ooooo`03
o`000?oooooooooo047ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Rooooo`00
GOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04kooooo0_l00013ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0H_ooool005gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`1Rooooo`00GOooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo04kooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo06;ooooo001Mooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0C_ooool00ol0
003oooooooooo`14ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0H_ooool005go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo04Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Rooooo`00G_ooool01Ol0003ooooo
oooooooooooo0000053ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo06;ooooo001Nooooo`05o`000?ooooooooooooooool00000D?ooool00ol0003o
ooooooooo`16ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_ooool005kooooo
00Go0000ooooooooooooooooo`00001@ooooo`;o0000B?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo06;ooooo001Oooooo`04o`000?ooooooooooo`00053ooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06;ooooo001Oooooo`04o`00
0?ooooooooooo`00053ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo06;ooooo001Pooooo`03o`000?oooooo0000053ooooo00?o0000ooooooooool0
BOooool01Ol0003ooooooooooooooooo000006Cooooo001Pooooo`03o`000?oooooo000003Kooooo
1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool0BOooool01Ol0003ooooooooooooooooo000006Cooooo001Pooooo`03
o`000?oooooo000003Sooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`1:ooooo`04o`000?ooooooooooo`0006Cooooo001Qooooo`;o
0000>?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0B_ooool01?l0003oooooooooool0001Tooooo`00HOooool2o`0003Sooooo00?o0000oooooooo
ool03_ooool00omgMgOo<S8booooo`04ooooo`?o0000Boooool00ol0003oooooo`00001Tooooo`00
H_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo04cooooo0_l0001Tooooo`00H_ooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`1<ooooo`;o0000I?ooool006;ooooo00?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0COooool00ol0003ooooooooo
o`1Rooooo`00H_ooool00ol0003oooooooooo`0dooooo`03oeEEEOmVIVKo000000gooooo1?l00006
ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0H_ooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.15712, -1.64371, \
0.0219855, 0.0185722}}],

Cell[BoxData[
    FormBox[
      TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
        False,
        Editable->False], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(bestimmt = \((int /. x \[Rule] 2)\) - \((int /. 
            x \[Rule] 1)\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\[Pi]\/4 - \(tan\^\(-1\)\)(2)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(N[bestimmt]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(-0.32175055439664213`\)\)], "Output"]
}, Open  ]]
},
FrontEndVersion->"5.2 for Macintosh",
ScreenRectangle->{{0, 1440}, {0, 884}},
WindowSize->{520, 740},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 203, 4, 90, "Input"],
Cell[1960, 57, 823, 14, 318, "Input"],

Cell[CellGroupData[{
Cell[2808, 75, 93, 1, 61, "Input"],
Cell[2904, 78, 109, 2, 56, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3050, 85, 59, 1, 33, "Input"],
Cell[3112, 88, 247, 4, 52, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3396, 97, 57, 1, 33, "Input"],
Cell[3456, 100, 28384, 636, 233, 4658, 339, "GraphicsData", "PostScript", \
"Graphics"],
Cell[31843, 738, 167, 4, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32047, 747, 202, 4, 109, "Input"],
Cell[32252, 753, 99, 2, 56, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32388, 760, 63, 1, 33, "Input"],
Cell[32454, 763, 28557, 623, 233, 4364, 320, "GraphicsData", "PostScript", \
"Graphics"],
Cell[61014, 1388, 167, 4, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[61218, 1397, 51, 1, 33, "Input"],
Cell[61272, 1400, 25722, 580, 233, 4468, 313, "GraphicsData", "PostScript", \
"Graphics"],
Cell[86997, 1982, 167, 4, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[87201, 1991, 93, 1, 33, "Input"],
Cell[87297, 1994, 289, 4, 93, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[87623, 2003, 44, 1, 33, "Input"],
Cell[87670, 2006, 103, 2, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[87810, 2013, 108, 2, 33, "Input"],
Cell[87921, 2017, 80, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[88038, 2023, 44, 1, 33, "Input"],
Cell[88085, 2026, 76, 1, 33, "Output"]
}, Open  ]],
Cell[88176, 2030, 48, 0, 36, "Text"],

Cell[CellGroupData[{
Cell[88249, 2034, 81, 1, 54, "Input"],
Cell[88333, 2037, 87, 1, 52, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[88457, 2043, 44, 1, 33, "Input"],
Cell[88504, 2046, 69, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[88610, 2052, 69, 1, 52, "Input"],
Cell[88682, 2055, 189, 4, 56, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[88908, 2064, 58, 1, 33, "Input"],
Cell[88969, 2067, 42544, 817, 233, 4731, 346, "GraphicsData", "PostScript", \
"Graphics"],
Cell[131516, 2886, 167, 4, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[131720, 2895, 108, 2, 33, "Input"],
Cell[131831, 2899, 80, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[131948, 2905, 44, 1, 33, "Input"],
Cell[131995, 2908, 76, 1, 33, "Output"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

